# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'PolicyPolicyRole',
    'PolicyPolicyRolePolicyScope',
    'PolicyPolicyUser',
    'PolicyPolicyUserGroup',
    'PolicyPolicyUserGroupPolicyScope',
    'PolicyPolicyUserPolicyScope',
    'RolePolicy',
    'RoleTag',
    'UserAccessKey',
    'UserLoginProfile',
    'UserPolicy',
    'UserSecurityConfig',
    'UserTag',
    'GetPolicyPolicyRoleResult',
    'GetPolicyPolicyRolePolicyScopeResult',
    'GetPolicyPolicyUserResult',
    'GetPolicyPolicyUserGroupResult',
    'GetPolicyPolicyUserGroupPolicyScopeResult',
    'GetPolicyPolicyUserPolicyScopeResult',
    'GetRolePolicyResult',
    'GetRoleTagResult',
    'GetUserAccessKeyResult',
    'GetUserLoginProfileResult',
    'GetUserPolicyResult',
    'GetUserSecurityConfigResult',
    'GetUserTagResult',
]

@pulumi.output_type
class PolicyPolicyRole(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "policyScopes":
            suggest = "policy_scopes"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in PolicyPolicyRole. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        PolicyPolicyRole.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        PolicyPolicyRole.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 name: Optional[builtins.str] = None,
                 policy_scopes: Optional[Sequence['outputs.PolicyPolicyRolePolicyScope']] = None):
        """
        :param builtins.str name: 对应用户、角色、用户组的名称。
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if policy_scopes is not None:
            pulumi.set(__self__, "policy_scopes", policy_scopes)

    @property
    @pulumi.getter
    def name(self) -> Optional[builtins.str]:
        """
        对应用户、角色、用户组的名称。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="policyScopes")
    def policy_scopes(self) -> Optional[Sequence['outputs.PolicyPolicyRolePolicyScope']]:
        return pulumi.get(self, "policy_scopes")


@pulumi.output_type
class PolicyPolicyRolePolicyScope(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "projectName":
            suggest = "project_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in PolicyPolicyRolePolicyScope. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        PolicyPolicyRolePolicyScope.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        PolicyPolicyRolePolicyScope.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 project_name: Optional[builtins.str] = None):
        """
        :param builtins.str project_name: 项目名。
        """
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[builtins.str]:
        """
        项目名。
        """
        return pulumi.get(self, "project_name")


@pulumi.output_type
class PolicyPolicyUser(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "policyScopes":
            suggest = "policy_scopes"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in PolicyPolicyUser. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        PolicyPolicyUser.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        PolicyPolicyUser.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 name: Optional[builtins.str] = None,
                 policy_scopes: Optional[Sequence['outputs.PolicyPolicyUserPolicyScope']] = None):
        """
        :param builtins.str name: 对应用户、角色、用户组的名称。
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if policy_scopes is not None:
            pulumi.set(__self__, "policy_scopes", policy_scopes)

    @property
    @pulumi.getter
    def name(self) -> Optional[builtins.str]:
        """
        对应用户、角色、用户组的名称。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="policyScopes")
    def policy_scopes(self) -> Optional[Sequence['outputs.PolicyPolicyUserPolicyScope']]:
        return pulumi.get(self, "policy_scopes")


@pulumi.output_type
class PolicyPolicyUserGroup(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "policyScopes":
            suggest = "policy_scopes"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in PolicyPolicyUserGroup. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        PolicyPolicyUserGroup.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        PolicyPolicyUserGroup.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 name: Optional[builtins.str] = None,
                 policy_scopes: Optional[Sequence['outputs.PolicyPolicyUserGroupPolicyScope']] = None):
        """
        :param builtins.str name: 对应用户、角色、用户组的名称。
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if policy_scopes is not None:
            pulumi.set(__self__, "policy_scopes", policy_scopes)

    @property
    @pulumi.getter
    def name(self) -> Optional[builtins.str]:
        """
        对应用户、角色、用户组的名称。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="policyScopes")
    def policy_scopes(self) -> Optional[Sequence['outputs.PolicyPolicyUserGroupPolicyScope']]:
        return pulumi.get(self, "policy_scopes")


@pulumi.output_type
class PolicyPolicyUserGroupPolicyScope(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "projectName":
            suggest = "project_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in PolicyPolicyUserGroupPolicyScope. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        PolicyPolicyUserGroupPolicyScope.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        PolicyPolicyUserGroupPolicyScope.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 project_name: Optional[builtins.str] = None):
        """
        :param builtins.str project_name: 项目名。
        """
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[builtins.str]:
        """
        项目名。
        """
        return pulumi.get(self, "project_name")


@pulumi.output_type
class PolicyPolicyUserPolicyScope(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "projectName":
            suggest = "project_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in PolicyPolicyUserPolicyScope. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        PolicyPolicyUserPolicyScope.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        PolicyPolicyUserPolicyScope.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 project_name: Optional[builtins.str] = None):
        """
        :param builtins.str project_name: 项目名。
        """
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[builtins.str]:
        """
        项目名。
        """
        return pulumi.get(self, "project_name")


@pulumi.output_type
class RolePolicy(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "policyName":
            suggest = "policy_name"
        elif key == "policyType":
            suggest = "policy_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RolePolicy. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RolePolicy.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RolePolicy.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 policy_name: Optional[builtins.str] = None,
                 policy_type: Optional[builtins.str] = None):
        """
        :param builtins.str policy_name: 策略名。
        :param builtins.str policy_type: 策略类型，策略类型。System代表系统预设策略，Custom代表自定义策略。
        """
        if policy_name is not None:
            pulumi.set(__self__, "policy_name", policy_name)
        if policy_type is not None:
            pulumi.set(__self__, "policy_type", policy_type)

    @property
    @pulumi.getter(name="policyName")
    def policy_name(self) -> Optional[builtins.str]:
        """
        策略名。
        """
        return pulumi.get(self, "policy_name")

    @property
    @pulumi.getter(name="policyType")
    def policy_type(self) -> Optional[builtins.str]:
        """
        策略类型，策略类型。System代表系统预设策略，Custom代表自定义策略。
        """
        return pulumi.get(self, "policy_type")


@pulumi.output_type
class RoleTag(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: 标签键。
        :param builtins.str value: 标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class UserAccessKey(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "accessKeyId":
            suggest = "access_key_id"
        elif key == "createdTime":
            suggest = "created_time"
        elif key == "requestTime":
            suggest = "request_time"
        elif key == "updatedTime":
            suggest = "updated_time"
        elif key == "userName":
            suggest = "user_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in UserAccessKey. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        UserAccessKey.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        UserAccessKey.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 access_key_id: Optional[builtins.str] = None,
                 created_time: Optional[builtins.str] = None,
                 region: Optional[builtins.str] = None,
                 request_time: Optional[builtins.str] = None,
                 service: Optional[builtins.str] = None,
                 status: Optional[builtins.str] = None,
                 updated_time: Optional[builtins.str] = None,
                 user_name: Optional[builtins.str] = None):
        """
        :param builtins.str access_key_id: 访问密钥ID。
        :param builtins.str created_time: 访问密钥创建时间。
        :param builtins.str region: 最近一次使用的服务区域。
        :param builtins.str request_time: 访问密钥最近一次使用时间。
        :param builtins.str service: 最近一次使用的服务名称。
        :param builtins.str status: 访问密钥状态。Active代表启用，Inactive代表禁用。
        :param builtins.str updated_time: 访问密钥更新时间。
        :param builtins.str user_name: 访问密钥Secret。
        """
        if access_key_id is not None:
            pulumi.set(__self__, "access_key_id", access_key_id)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if request_time is not None:
            pulumi.set(__self__, "request_time", request_time)
        if service is not None:
            pulumi.set(__self__, "service", service)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)
        if user_name is not None:
            pulumi.set(__self__, "user_name", user_name)

    @property
    @pulumi.getter(name="accessKeyId")
    def access_key_id(self) -> Optional[builtins.str]:
        """
        访问密钥ID。
        """
        return pulumi.get(self, "access_key_id")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[builtins.str]:
        """
        访问密钥创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def region(self) -> Optional[builtins.str]:
        """
        最近一次使用的服务区域。
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="requestTime")
    def request_time(self) -> Optional[builtins.str]:
        """
        访问密钥最近一次使用时间。
        """
        return pulumi.get(self, "request_time")

    @property
    @pulumi.getter
    def service(self) -> Optional[builtins.str]:
        """
        最近一次使用的服务名称。
        """
        return pulumi.get(self, "service")

    @property
    @pulumi.getter
    def status(self) -> Optional[builtins.str]:
        """
        访问密钥状态。Active代表启用，Inactive代表禁用。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[builtins.str]:
        """
        访问密钥更新时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> Optional[builtins.str]:
        """
        访问密钥Secret。
        """
        return pulumi.get(self, "user_name")


@pulumi.output_type
class UserLoginProfile(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "createDate":
            suggest = "create_date"
        elif key == "lastLoginDate":
            suggest = "last_login_date"
        elif key == "lastLoginIp":
            suggest = "last_login_ip"
        elif key == "lastResetPasswordTime":
            suggest = "last_reset_password_time"
        elif key == "loginAllowed":
            suggest = "login_allowed"
        elif key == "loginLocked":
            suggest = "login_locked"
        elif key == "passwordExpireAt":
            suggest = "password_expire_at"
        elif key == "passwordResetRequired":
            suggest = "password_reset_required"
        elif key == "safeAuthExemptDuration":
            suggest = "safe_auth_exempt_duration"
        elif key == "safeAuthExemptRequired":
            suggest = "safe_auth_exempt_required"
        elif key == "safeAuthExemptUnit":
            suggest = "safe_auth_exempt_unit"
        elif key == "safeAuthFlag":
            suggest = "safe_auth_flag"
        elif key == "safeAuthType":
            suggest = "safe_auth_type"
        elif key == "updateDate":
            suggest = "update_date"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in UserLoginProfile. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        UserLoginProfile.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        UserLoginProfile.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 create_date: Optional[builtins.str] = None,
                 last_login_date: Optional[builtins.str] = None,
                 last_login_ip: Optional[builtins.str] = None,
                 last_reset_password_time: Optional[builtins.float] = None,
                 login_allowed: Optional[builtins.bool] = None,
                 login_locked: Optional[builtins.bool] = None,
                 password: Optional[builtins.str] = None,
                 password_expire_at: Optional[builtins.float] = None,
                 password_reset_required: Optional[builtins.bool] = None,
                 safe_auth_exempt_duration: Optional[builtins.float] = None,
                 safe_auth_exempt_required: Optional[builtins.float] = None,
                 safe_auth_exempt_unit: Optional[builtins.float] = None,
                 safe_auth_flag: Optional[builtins.bool] = None,
                 safe_auth_type: Optional[builtins.str] = None,
                 update_date: Optional[builtins.str] = None):
        """
        :param builtins.str create_date: 登录配置创建时间。
        :param builtins.str last_login_date: 上次登录时间。
        :param builtins.str last_login_ip: 上次登录IP。
        :param builtins.float last_reset_password_time: 上次重置密码的时间，上次重置密码的时间。0代表未设置过密码，非0代表过期时间的时间戳。
        :param builtins.bool login_allowed: 是否允许登录，是否允许登录。true代表允许，false代表不允许，默认为false。
        :param builtins.bool login_locked: 登录是否被锁定。true代表已锁定，false代表未锁定。管理员设置错误密码重试次数限制后，用户命中后登录会被锁定。
        :param builtins.str password: 登录密码。
        :param builtins.float password_expire_at: 密码过期时间。0代表永不过期，非0代表过期时间的时间戳。
        :param builtins.bool password_reset_required: 下次登录是否需要重设密码，下次登录是否需要重设密码。true代表允许，false代表不允许，默认为false。
        :param builtins.float safe_auth_exempt_duration: 登录保护豁免时长，登录保护豁免时长。支持设置1至7（天），或1至168（小时），或5至1440（分钟）。单位设置请参考SafeAuthExemptUnit参数。
        :param builtins.float safe_auth_exempt_required: 是否开启登录保护豁免，是否开启登录保护豁免。0代表不开启，1代表开启。开启登录保护豁免后，验证完成后一定时间内登录将不再进行验证。
        :param builtins.float safe_auth_exempt_unit: 登录保护豁免的时间单位，登录保护豁免的时间单位。0代表分钟，1代表小时，2代表天。
        :param builtins.bool safe_auth_flag: 是否开启登录保护，是否开启登录保护。true代表开启，false代表不开启，默认为false。
        :param builtins.str safe_auth_type: 登录保护类型，登录保护类型。phone代表手机验证，email代表邮箱验证，vmfa代表验证MFA设备验证。支持设置多种操作保护类型，以英文逗号分隔。可选vmfa, phone, email, 多个选项逗号隔开。
        :param builtins.str update_date: 登录配置更新时间。
        """
        if create_date is not None:
            pulumi.set(__self__, "create_date", create_date)
        if last_login_date is not None:
            pulumi.set(__self__, "last_login_date", last_login_date)
        if last_login_ip is not None:
            pulumi.set(__self__, "last_login_ip", last_login_ip)
        if last_reset_password_time is not None:
            pulumi.set(__self__, "last_reset_password_time", last_reset_password_time)
        if login_allowed is not None:
            pulumi.set(__self__, "login_allowed", login_allowed)
        if login_locked is not None:
            pulumi.set(__self__, "login_locked", login_locked)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if password_expire_at is not None:
            pulumi.set(__self__, "password_expire_at", password_expire_at)
        if password_reset_required is not None:
            pulumi.set(__self__, "password_reset_required", password_reset_required)
        if safe_auth_exempt_duration is not None:
            pulumi.set(__self__, "safe_auth_exempt_duration", safe_auth_exempt_duration)
        if safe_auth_exempt_required is not None:
            pulumi.set(__self__, "safe_auth_exempt_required", safe_auth_exempt_required)
        if safe_auth_exempt_unit is not None:
            pulumi.set(__self__, "safe_auth_exempt_unit", safe_auth_exempt_unit)
        if safe_auth_flag is not None:
            pulumi.set(__self__, "safe_auth_flag", safe_auth_flag)
        if safe_auth_type is not None:
            pulumi.set(__self__, "safe_auth_type", safe_auth_type)
        if update_date is not None:
            pulumi.set(__self__, "update_date", update_date)

    @property
    @pulumi.getter(name="createDate")
    def create_date(self) -> Optional[builtins.str]:
        """
        登录配置创建时间。
        """
        return pulumi.get(self, "create_date")

    @property
    @pulumi.getter(name="lastLoginDate")
    def last_login_date(self) -> Optional[builtins.str]:
        """
        上次登录时间。
        """
        return pulumi.get(self, "last_login_date")

    @property
    @pulumi.getter(name="lastLoginIp")
    def last_login_ip(self) -> Optional[builtins.str]:
        """
        上次登录IP。
        """
        return pulumi.get(self, "last_login_ip")

    @property
    @pulumi.getter(name="lastResetPasswordTime")
    def last_reset_password_time(self) -> Optional[builtins.float]:
        """
        上次重置密码的时间，上次重置密码的时间。0代表未设置过密码，非0代表过期时间的时间戳。
        """
        return pulumi.get(self, "last_reset_password_time")

    @property
    @pulumi.getter(name="loginAllowed")
    def login_allowed(self) -> Optional[builtins.bool]:
        """
        是否允许登录，是否允许登录。true代表允许，false代表不允许，默认为false。
        """
        return pulumi.get(self, "login_allowed")

    @property
    @pulumi.getter(name="loginLocked")
    def login_locked(self) -> Optional[builtins.bool]:
        """
        登录是否被锁定。true代表已锁定，false代表未锁定。管理员设置错误密码重试次数限制后，用户命中后登录会被锁定。
        """
        return pulumi.get(self, "login_locked")

    @property
    @pulumi.getter
    def password(self) -> Optional[builtins.str]:
        """
        登录密码。
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="passwordExpireAt")
    def password_expire_at(self) -> Optional[builtins.float]:
        """
        密码过期时间。0代表永不过期，非0代表过期时间的时间戳。
        """
        return pulumi.get(self, "password_expire_at")

    @property
    @pulumi.getter(name="passwordResetRequired")
    def password_reset_required(self) -> Optional[builtins.bool]:
        """
        下次登录是否需要重设密码，下次登录是否需要重设密码。true代表允许，false代表不允许，默认为false。
        """
        return pulumi.get(self, "password_reset_required")

    @property
    @pulumi.getter(name="safeAuthExemptDuration")
    def safe_auth_exempt_duration(self) -> Optional[builtins.float]:
        """
        登录保护豁免时长，登录保护豁免时长。支持设置1至7（天），或1至168（小时），或5至1440（分钟）。单位设置请参考SafeAuthExemptUnit参数。
        """
        return pulumi.get(self, "safe_auth_exempt_duration")

    @property
    @pulumi.getter(name="safeAuthExemptRequired")
    def safe_auth_exempt_required(self) -> Optional[builtins.float]:
        """
        是否开启登录保护豁免，是否开启登录保护豁免。0代表不开启，1代表开启。开启登录保护豁免后，验证完成后一定时间内登录将不再进行验证。
        """
        return pulumi.get(self, "safe_auth_exempt_required")

    @property
    @pulumi.getter(name="safeAuthExemptUnit")
    def safe_auth_exempt_unit(self) -> Optional[builtins.float]:
        """
        登录保护豁免的时间单位，登录保护豁免的时间单位。0代表分钟，1代表小时，2代表天。
        """
        return pulumi.get(self, "safe_auth_exempt_unit")

    @property
    @pulumi.getter(name="safeAuthFlag")
    def safe_auth_flag(self) -> Optional[builtins.bool]:
        """
        是否开启登录保护，是否开启登录保护。true代表开启，false代表不开启，默认为false。
        """
        return pulumi.get(self, "safe_auth_flag")

    @property
    @pulumi.getter(name="safeAuthType")
    def safe_auth_type(self) -> Optional[builtins.str]:
        """
        登录保护类型，登录保护类型。phone代表手机验证，email代表邮箱验证，vmfa代表验证MFA设备验证。支持设置多种操作保护类型，以英文逗号分隔。可选vmfa, phone, email, 多个选项逗号隔开。
        """
        return pulumi.get(self, "safe_auth_type")

    @property
    @pulumi.getter(name="updateDate")
    def update_date(self) -> Optional[builtins.str]:
        """
        登录配置更新时间。
        """
        return pulumi.get(self, "update_date")


@pulumi.output_type
class UserPolicy(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "policyName":
            suggest = "policy_name"
        elif key == "policyType":
            suggest = "policy_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in UserPolicy. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        UserPolicy.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        UserPolicy.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 policy_name: Optional[builtins.str] = None,
                 policy_type: Optional[builtins.str] = None):
        """
        :param builtins.str policy_name: 权限策略名称，长度1~64，支持英文、数字和+=,.@-_符号。
        :param builtins.str policy_type: 权限策略类型，策略类型。System代表系统预设策略，Custom代表自定义策略。
        """
        if policy_name is not None:
            pulumi.set(__self__, "policy_name", policy_name)
        if policy_type is not None:
            pulumi.set(__self__, "policy_type", policy_type)

    @property
    @pulumi.getter(name="policyName")
    def policy_name(self) -> Optional[builtins.str]:
        """
        权限策略名称，长度1~64，支持英文、数字和+=,.@-_符号。
        """
        return pulumi.get(self, "policy_name")

    @property
    @pulumi.getter(name="policyType")
    def policy_type(self) -> Optional[builtins.str]:
        """
        权限策略类型，策略类型。System代表系统预设策略，Custom代表自定义策略。
        """
        return pulumi.get(self, "policy_type")


@pulumi.output_type
class UserSecurityConfig(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "safeAuthClose":
            suggest = "safe_auth_close"
        elif key == "safeAuthExemptDuration":
            suggest = "safe_auth_exempt_duration"
        elif key == "safeAuthType":
            suggest = "safe_auth_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in UserSecurityConfig. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        UserSecurityConfig.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        UserSecurityConfig.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 safe_auth_close: Optional[builtins.float] = None,
                 safe_auth_exempt_duration: Optional[builtins.float] = None,
                 safe_auth_type: Optional[builtins.str] = None):
        """
        :param builtins.float safe_auth_close: 是否开启操作保护。0代表开启，1代表关闭。
        :param builtins.float safe_auth_exempt_duration: 操作保护的豁免时间，完成验证后在豁免时间内将不再进行验证。支持设置5至30，默认值为10。单位为分钟。
        :param builtins.str safe_auth_type: 操作保护类型。phone代表手机验证，email代表邮箱验证，vmfa代表验证MFA设备验证。支持设置多种操作保护类型，以英文逗号分隔。
        """
        if safe_auth_close is not None:
            pulumi.set(__self__, "safe_auth_close", safe_auth_close)
        if safe_auth_exempt_duration is not None:
            pulumi.set(__self__, "safe_auth_exempt_duration", safe_auth_exempt_duration)
        if safe_auth_type is not None:
            pulumi.set(__self__, "safe_auth_type", safe_auth_type)

    @property
    @pulumi.getter(name="safeAuthClose")
    def safe_auth_close(self) -> Optional[builtins.float]:
        """
        是否开启操作保护。0代表开启，1代表关闭。
        """
        return pulumi.get(self, "safe_auth_close")

    @property
    @pulumi.getter(name="safeAuthExemptDuration")
    def safe_auth_exempt_duration(self) -> Optional[builtins.float]:
        """
        操作保护的豁免时间，完成验证后在豁免时间内将不再进行验证。支持设置5至30，默认值为10。单位为分钟。
        """
        return pulumi.get(self, "safe_auth_exempt_duration")

    @property
    @pulumi.getter(name="safeAuthType")
    def safe_auth_type(self) -> Optional[builtins.str]:
        """
        操作保护类型。phone代表手机验证，email代表邮箱验证，vmfa代表验证MFA设备验证。支持设置多种操作保护类型，以英文逗号分隔。
        """
        return pulumi.get(self, "safe_auth_type")


@pulumi.output_type
class UserTag(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: 标签键。
        :param builtins.str value: 标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetPolicyPolicyRoleResult(dict):
    def __init__(__self__, *,
                 created_time: builtins.str,
                 description: builtins.str,
                 display_name: builtins.str,
                 entities_id: builtins.int,
                 name: builtins.str,
                 policy_scopes: Sequence['outputs.GetPolicyPolicyRolePolicyScopeResult']):
        """
        :param builtins.str created_time: 策略绑定时间。
        :param builtins.str description: 策略描述。
        :param builtins.str display_name: 显示名称。
        :param builtins.int entities_id: 唯一标识。
        :param builtins.str name: 对应用户、角色、用户组的名称。
        :param Sequence['GetPolicyPolicyRolePolicyScopeArgs'] policy_scopes: 策略绑定的项目列表。
        """
        pulumi.set(__self__, "created_time", created_time)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "entities_id", entities_id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "policy_scopes", policy_scopes)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        策略绑定时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        策略描述。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> builtins.str:
        """
        显示名称。
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="entitiesId")
    def entities_id(self) -> builtins.int:
        """
        唯一标识。
        """
        return pulumi.get(self, "entities_id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        对应用户、角色、用户组的名称。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="policyScopes")
    def policy_scopes(self) -> Sequence['outputs.GetPolicyPolicyRolePolicyScopeResult']:
        """
        策略绑定的项目列表。
        """
        return pulumi.get(self, "policy_scopes")


@pulumi.output_type
class GetPolicyPolicyRolePolicyScopeResult(dict):
    def __init__(__self__, *,
                 created_time: builtins.str,
                 policy_scope_type: builtins.str,
                 project_display_name: builtins.str,
                 project_name: builtins.str):
        """
        :param builtins.str created_time: 项目授权时间。
        :param builtins.str policy_scope_type: 授权类型。Global代表全局授权，Project代表按项目授权。
        :param builtins.str project_display_name: 项目显示名。
        :param builtins.str project_name: 项目名。
        """
        pulumi.set(__self__, "created_time", created_time)
        pulumi.set(__self__, "policy_scope_type", policy_scope_type)
        pulumi.set(__self__, "project_display_name", project_display_name)
        pulumi.set(__self__, "project_name", project_name)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        项目授权时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="policyScopeType")
    def policy_scope_type(self) -> builtins.str:
        """
        授权类型。Global代表全局授权，Project代表按项目授权。
        """
        return pulumi.get(self, "policy_scope_type")

    @property
    @pulumi.getter(name="projectDisplayName")
    def project_display_name(self) -> builtins.str:
        """
        项目显示名。
        """
        return pulumi.get(self, "project_display_name")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        项目名。
        """
        return pulumi.get(self, "project_name")


@pulumi.output_type
class GetPolicyPolicyUserResult(dict):
    def __init__(__self__, *,
                 created_time: builtins.str,
                 description: builtins.str,
                 display_name: builtins.str,
                 entities_id: builtins.int,
                 name: builtins.str,
                 policy_scopes: Sequence['outputs.GetPolicyPolicyUserPolicyScopeResult']):
        """
        :param builtins.str created_time: 策略绑定时间。
        :param builtins.str description: 策略描述。
        :param builtins.str display_name: 显示名称。
        :param builtins.int entities_id: 唯一标识。
        :param builtins.str name: 对应用户、角色、用户组的名称。
        :param Sequence['GetPolicyPolicyUserPolicyScopeArgs'] policy_scopes: 策略绑定的项目列表。
        """
        pulumi.set(__self__, "created_time", created_time)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "entities_id", entities_id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "policy_scopes", policy_scopes)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        策略绑定时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        策略描述。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> builtins.str:
        """
        显示名称。
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="entitiesId")
    def entities_id(self) -> builtins.int:
        """
        唯一标识。
        """
        return pulumi.get(self, "entities_id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        对应用户、角色、用户组的名称。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="policyScopes")
    def policy_scopes(self) -> Sequence['outputs.GetPolicyPolicyUserPolicyScopeResult']:
        """
        策略绑定的项目列表。
        """
        return pulumi.get(self, "policy_scopes")


@pulumi.output_type
class GetPolicyPolicyUserGroupResult(dict):
    def __init__(__self__, *,
                 created_time: builtins.str,
                 description: builtins.str,
                 display_name: builtins.str,
                 entities_id: builtins.int,
                 name: builtins.str,
                 policy_scopes: Sequence['outputs.GetPolicyPolicyUserGroupPolicyScopeResult']):
        """
        :param builtins.str created_time: 策略绑定时间。
        :param builtins.str description: 策略描述。
        :param builtins.str display_name: 显示名称。
        :param builtins.int entities_id: 唯一标识。
        :param builtins.str name: 对应用户、角色、用户组的名称。
        :param Sequence['GetPolicyPolicyUserGroupPolicyScopeArgs'] policy_scopes: 策略绑定的项目列表。
        """
        pulumi.set(__self__, "created_time", created_time)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "entities_id", entities_id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "policy_scopes", policy_scopes)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        策略绑定时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        策略描述。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> builtins.str:
        """
        显示名称。
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="entitiesId")
    def entities_id(self) -> builtins.int:
        """
        唯一标识。
        """
        return pulumi.get(self, "entities_id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        对应用户、角色、用户组的名称。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="policyScopes")
    def policy_scopes(self) -> Sequence['outputs.GetPolicyPolicyUserGroupPolicyScopeResult']:
        """
        策略绑定的项目列表。
        """
        return pulumi.get(self, "policy_scopes")


@pulumi.output_type
class GetPolicyPolicyUserGroupPolicyScopeResult(dict):
    def __init__(__self__, *,
                 created_time: builtins.str,
                 policy_scope_type: builtins.str,
                 project_display_name: builtins.str,
                 project_name: builtins.str):
        """
        :param builtins.str created_time: 项目授权时间。
        :param builtins.str policy_scope_type: 授权类型。Global代表全局授权，Project代表按项目授权。
        :param builtins.str project_display_name: 项目显示名。
        :param builtins.str project_name: 项目名。
        """
        pulumi.set(__self__, "created_time", created_time)
        pulumi.set(__self__, "policy_scope_type", policy_scope_type)
        pulumi.set(__self__, "project_display_name", project_display_name)
        pulumi.set(__self__, "project_name", project_name)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        项目授权时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="policyScopeType")
    def policy_scope_type(self) -> builtins.str:
        """
        授权类型。Global代表全局授权，Project代表按项目授权。
        """
        return pulumi.get(self, "policy_scope_type")

    @property
    @pulumi.getter(name="projectDisplayName")
    def project_display_name(self) -> builtins.str:
        """
        项目显示名。
        """
        return pulumi.get(self, "project_display_name")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        项目名。
        """
        return pulumi.get(self, "project_name")


@pulumi.output_type
class GetPolicyPolicyUserPolicyScopeResult(dict):
    def __init__(__self__, *,
                 created_time: builtins.str,
                 policy_scope_type: builtins.str,
                 project_display_name: builtins.str,
                 project_name: builtins.str):
        """
        :param builtins.str created_time: 项目授权时间。
        :param builtins.str policy_scope_type: 授权类型。Global代表全局授权，Project代表按项目授权。
        :param builtins.str project_display_name: 项目显示名。
        :param builtins.str project_name: 项目名。
        """
        pulumi.set(__self__, "created_time", created_time)
        pulumi.set(__self__, "policy_scope_type", policy_scope_type)
        pulumi.set(__self__, "project_display_name", project_display_name)
        pulumi.set(__self__, "project_name", project_name)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        项目授权时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="policyScopeType")
    def policy_scope_type(self) -> builtins.str:
        """
        授权类型。Global代表全局授权，Project代表按项目授权。
        """
        return pulumi.get(self, "policy_scope_type")

    @property
    @pulumi.getter(name="projectDisplayName")
    def project_display_name(self) -> builtins.str:
        """
        项目显示名。
        """
        return pulumi.get(self, "project_display_name")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        项目名。
        """
        return pulumi.get(self, "project_name")


@pulumi.output_type
class GetRolePolicyResult(dict):
    def __init__(__self__, *,
                 policy_name: builtins.str,
                 policy_type: builtins.str):
        """
        :param builtins.str policy_name: 策略名。
        :param builtins.str policy_type: 策略类型，策略类型。System代表系统预设策略，Custom代表自定义策略。
        """
        pulumi.set(__self__, "policy_name", policy_name)
        pulumi.set(__self__, "policy_type", policy_type)

    @property
    @pulumi.getter(name="policyName")
    def policy_name(self) -> builtins.str:
        """
        策略名。
        """
        return pulumi.get(self, "policy_name")

    @property
    @pulumi.getter(name="policyType")
    def policy_type(self) -> builtins.str:
        """
        策略类型，策略类型。System代表系统预设策略，Custom代表自定义策略。
        """
        return pulumi.get(self, "policy_type")


@pulumi.output_type
class GetRoleTagResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: 标签键。
        :param builtins.str value: 标签值。
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetUserAccessKeyResult(dict):
    def __init__(__self__, *,
                 access_key_id: builtins.str,
                 created_time: builtins.str,
                 region: builtins.str,
                 request_time: builtins.str,
                 service: builtins.str,
                 status: builtins.str,
                 updated_time: builtins.str,
                 user_name: builtins.str):
        """
        :param builtins.str access_key_id: 访问密钥ID。
        :param builtins.str created_time: 访问密钥创建时间。
        :param builtins.str region: 最近一次使用的服务区域。
        :param builtins.str request_time: 访问密钥最近一次使用时间。
        :param builtins.str service: 最近一次使用的服务名称。
        :param builtins.str status: 访问密钥状态。Active代表启用，Inactive代表禁用。
        :param builtins.str updated_time: 访问密钥更新时间。
        :param builtins.str user_name: 访问密钥Secret。
        """
        pulumi.set(__self__, "access_key_id", access_key_id)
        pulumi.set(__self__, "created_time", created_time)
        pulumi.set(__self__, "region", region)
        pulumi.set(__self__, "request_time", request_time)
        pulumi.set(__self__, "service", service)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "updated_time", updated_time)
        pulumi.set(__self__, "user_name", user_name)

    @property
    @pulumi.getter(name="accessKeyId")
    def access_key_id(self) -> builtins.str:
        """
        访问密钥ID。
        """
        return pulumi.get(self, "access_key_id")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        访问密钥创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def region(self) -> builtins.str:
        """
        最近一次使用的服务区域。
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="requestTime")
    def request_time(self) -> builtins.str:
        """
        访问密钥最近一次使用时间。
        """
        return pulumi.get(self, "request_time")

    @property
    @pulumi.getter
    def service(self) -> builtins.str:
        """
        最近一次使用的服务名称。
        """
        return pulumi.get(self, "service")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        访问密钥状态。Active代表启用，Inactive代表禁用。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        访问密钥更新时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> builtins.str:
        """
        访问密钥Secret。
        """
        return pulumi.get(self, "user_name")


@pulumi.output_type
class GetUserLoginProfileResult(dict):
    def __init__(__self__, *,
                 create_date: builtins.str,
                 last_login_date: builtins.str,
                 last_login_ip: builtins.str,
                 last_reset_password_time: builtins.float,
                 login_allowed: builtins.bool,
                 login_locked: builtins.bool,
                 password: builtins.str,
                 password_expire_at: builtins.float,
                 password_reset_required: builtins.bool,
                 safe_auth_exempt_duration: builtins.float,
                 safe_auth_exempt_required: builtins.float,
                 safe_auth_exempt_unit: builtins.float,
                 safe_auth_flag: builtins.bool,
                 safe_auth_type: builtins.str,
                 update_date: builtins.str):
        """
        :param builtins.str create_date: 登录配置创建时间。
        :param builtins.str last_login_date: 上次登录时间。
        :param builtins.str last_login_ip: 上次登录IP。
        :param builtins.float last_reset_password_time: 上次重置密码的时间，上次重置密码的时间。0代表未设置过密码，非0代表过期时间的时间戳。
        :param builtins.bool login_allowed: 是否允许登录，是否允许登录。true代表允许，false代表不允许，默认为false。
        :param builtins.bool login_locked: 登录是否被锁定。true代表已锁定，false代表未锁定。管理员设置错误密码重试次数限制后，用户命中后登录会被锁定。
        :param builtins.str password: 登录密码。
        :param builtins.float password_expire_at: 密码过期时间。0代表永不过期，非0代表过期时间的时间戳。
        :param builtins.bool password_reset_required: 下次登录是否需要重设密码，下次登录是否需要重设密码。true代表允许，false代表不允许，默认为false。
        :param builtins.float safe_auth_exempt_duration: 登录保护豁免时长，登录保护豁免时长。支持设置1至7（天），或1至168（小时），或5至1440（分钟）。单位设置请参考SafeAuthExemptUnit参数。
        :param builtins.float safe_auth_exempt_required: 是否开启登录保护豁免，是否开启登录保护豁免。0代表不开启，1代表开启。开启登录保护豁免后，验证完成后一定时间内登录将不再进行验证。
        :param builtins.float safe_auth_exempt_unit: 登录保护豁免的时间单位，登录保护豁免的时间单位。0代表分钟，1代表小时，2代表天。
        :param builtins.bool safe_auth_flag: 是否开启登录保护，是否开启登录保护。true代表开启，false代表不开启，默认为false。
        :param builtins.str safe_auth_type: 登录保护类型，登录保护类型。phone代表手机验证，email代表邮箱验证，vmfa代表验证MFA设备验证。支持设置多种操作保护类型，以英文逗号分隔。可选vmfa, phone, email, 多个选项逗号隔开。
        :param builtins.str update_date: 登录配置更新时间。
        """
        pulumi.set(__self__, "create_date", create_date)
        pulumi.set(__self__, "last_login_date", last_login_date)
        pulumi.set(__self__, "last_login_ip", last_login_ip)
        pulumi.set(__self__, "last_reset_password_time", last_reset_password_time)
        pulumi.set(__self__, "login_allowed", login_allowed)
        pulumi.set(__self__, "login_locked", login_locked)
        pulumi.set(__self__, "password", password)
        pulumi.set(__self__, "password_expire_at", password_expire_at)
        pulumi.set(__self__, "password_reset_required", password_reset_required)
        pulumi.set(__self__, "safe_auth_exempt_duration", safe_auth_exempt_duration)
        pulumi.set(__self__, "safe_auth_exempt_required", safe_auth_exempt_required)
        pulumi.set(__self__, "safe_auth_exempt_unit", safe_auth_exempt_unit)
        pulumi.set(__self__, "safe_auth_flag", safe_auth_flag)
        pulumi.set(__self__, "safe_auth_type", safe_auth_type)
        pulumi.set(__self__, "update_date", update_date)

    @property
    @pulumi.getter(name="createDate")
    def create_date(self) -> builtins.str:
        """
        登录配置创建时间。
        """
        return pulumi.get(self, "create_date")

    @property
    @pulumi.getter(name="lastLoginDate")
    def last_login_date(self) -> builtins.str:
        """
        上次登录时间。
        """
        return pulumi.get(self, "last_login_date")

    @property
    @pulumi.getter(name="lastLoginIp")
    def last_login_ip(self) -> builtins.str:
        """
        上次登录IP。
        """
        return pulumi.get(self, "last_login_ip")

    @property
    @pulumi.getter(name="lastResetPasswordTime")
    def last_reset_password_time(self) -> builtins.float:
        """
        上次重置密码的时间，上次重置密码的时间。0代表未设置过密码，非0代表过期时间的时间戳。
        """
        return pulumi.get(self, "last_reset_password_time")

    @property
    @pulumi.getter(name="loginAllowed")
    def login_allowed(self) -> builtins.bool:
        """
        是否允许登录，是否允许登录。true代表允许，false代表不允许，默认为false。
        """
        return pulumi.get(self, "login_allowed")

    @property
    @pulumi.getter(name="loginLocked")
    def login_locked(self) -> builtins.bool:
        """
        登录是否被锁定。true代表已锁定，false代表未锁定。管理员设置错误密码重试次数限制后，用户命中后登录会被锁定。
        """
        return pulumi.get(self, "login_locked")

    @property
    @pulumi.getter
    def password(self) -> builtins.str:
        """
        登录密码。
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="passwordExpireAt")
    def password_expire_at(self) -> builtins.float:
        """
        密码过期时间。0代表永不过期，非0代表过期时间的时间戳。
        """
        return pulumi.get(self, "password_expire_at")

    @property
    @pulumi.getter(name="passwordResetRequired")
    def password_reset_required(self) -> builtins.bool:
        """
        下次登录是否需要重设密码，下次登录是否需要重设密码。true代表允许，false代表不允许，默认为false。
        """
        return pulumi.get(self, "password_reset_required")

    @property
    @pulumi.getter(name="safeAuthExemptDuration")
    def safe_auth_exempt_duration(self) -> builtins.float:
        """
        登录保护豁免时长，登录保护豁免时长。支持设置1至7（天），或1至168（小时），或5至1440（分钟）。单位设置请参考SafeAuthExemptUnit参数。
        """
        return pulumi.get(self, "safe_auth_exempt_duration")

    @property
    @pulumi.getter(name="safeAuthExemptRequired")
    def safe_auth_exempt_required(self) -> builtins.float:
        """
        是否开启登录保护豁免，是否开启登录保护豁免。0代表不开启，1代表开启。开启登录保护豁免后，验证完成后一定时间内登录将不再进行验证。
        """
        return pulumi.get(self, "safe_auth_exempt_required")

    @property
    @pulumi.getter(name="safeAuthExemptUnit")
    def safe_auth_exempt_unit(self) -> builtins.float:
        """
        登录保护豁免的时间单位，登录保护豁免的时间单位。0代表分钟，1代表小时，2代表天。
        """
        return pulumi.get(self, "safe_auth_exempt_unit")

    @property
    @pulumi.getter(name="safeAuthFlag")
    def safe_auth_flag(self) -> builtins.bool:
        """
        是否开启登录保护，是否开启登录保护。true代表开启，false代表不开启，默认为false。
        """
        return pulumi.get(self, "safe_auth_flag")

    @property
    @pulumi.getter(name="safeAuthType")
    def safe_auth_type(self) -> builtins.str:
        """
        登录保护类型，登录保护类型。phone代表手机验证，email代表邮箱验证，vmfa代表验证MFA设备验证。支持设置多种操作保护类型，以英文逗号分隔。可选vmfa, phone, email, 多个选项逗号隔开。
        """
        return pulumi.get(self, "safe_auth_type")

    @property
    @pulumi.getter(name="updateDate")
    def update_date(self) -> builtins.str:
        """
        登录配置更新时间。
        """
        return pulumi.get(self, "update_date")


@pulumi.output_type
class GetUserPolicyResult(dict):
    def __init__(__self__, *,
                 policy_name: builtins.str,
                 policy_type: builtins.str):
        """
        :param builtins.str policy_name: 权限策略名称，长度1~64，支持英文、数字和+=,.@-_符号。
        :param builtins.str policy_type: 权限策略类型，策略类型。System代表系统预设策略，Custom代表自定义策略。
        """
        pulumi.set(__self__, "policy_name", policy_name)
        pulumi.set(__self__, "policy_type", policy_type)

    @property
    @pulumi.getter(name="policyName")
    def policy_name(self) -> builtins.str:
        """
        权限策略名称，长度1~64，支持英文、数字和+=,.@-_符号。
        """
        return pulumi.get(self, "policy_name")

    @property
    @pulumi.getter(name="policyType")
    def policy_type(self) -> builtins.str:
        """
        权限策略类型，策略类型。System代表系统预设策略，Custom代表自定义策略。
        """
        return pulumi.get(self, "policy_type")


@pulumi.output_type
class GetUserSecurityConfigResult(dict):
    def __init__(__self__, *,
                 safe_auth_close: builtins.float,
                 safe_auth_exempt_duration: builtins.float,
                 safe_auth_type: builtins.str):
        """
        :param builtins.float safe_auth_close: 是否开启操作保护。0代表开启，1代表关闭。
        :param builtins.float safe_auth_exempt_duration: 操作保护的豁免时间，完成验证后在豁免时间内将不再进行验证。支持设置5至30，默认值为10。单位为分钟。
        :param builtins.str safe_auth_type: 操作保护类型。phone代表手机验证，email代表邮箱验证，vmfa代表验证MFA设备验证。支持设置多种操作保护类型，以英文逗号分隔。
        """
        pulumi.set(__self__, "safe_auth_close", safe_auth_close)
        pulumi.set(__self__, "safe_auth_exempt_duration", safe_auth_exempt_duration)
        pulumi.set(__self__, "safe_auth_type", safe_auth_type)

    @property
    @pulumi.getter(name="safeAuthClose")
    def safe_auth_close(self) -> builtins.float:
        """
        是否开启操作保护。0代表开启，1代表关闭。
        """
        return pulumi.get(self, "safe_auth_close")

    @property
    @pulumi.getter(name="safeAuthExemptDuration")
    def safe_auth_exempt_duration(self) -> builtins.float:
        """
        操作保护的豁免时间，完成验证后在豁免时间内将不再进行验证。支持设置5至30，默认值为10。单位为分钟。
        """
        return pulumi.get(self, "safe_auth_exempt_duration")

    @property
    @pulumi.getter(name="safeAuthType")
    def safe_auth_type(self) -> builtins.str:
        """
        操作保护类型。phone代表手机验证，email代表邮箱验证，vmfa代表验证MFA设备验证。支持设置多种操作保护类型，以英文逗号分隔。
        """
        return pulumi.get(self, "safe_auth_type")


@pulumi.output_type
class GetUserTagResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: 标签键。
        :param builtins.str value: 标签值。
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        标签值。
        """
        return pulumi.get(self, "value")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetDnatentryResult',
    'AwaitableGetDnatentryResult',
    'get_dnatentry',
    'get_dnatentry_output',
]

@pulumi.output_type
class GetDnatentryResult:
    """
    A collection of values returned by getDnatentry.
    """
    def __init__(__self__, dnat_entry_id=None, dnat_entry_name=None, external_ip=None, external_port=None, id=None, internal_ip=None, internal_port=None, nat_gateway_id=None, port_type=None, protocol=None, status=None):
        if dnat_entry_id and not isinstance(dnat_entry_id, str):
            raise TypeError("Expected argument 'dnat_entry_id' to be a str")
        pulumi.set(__self__, "dnat_entry_id", dnat_entry_id)
        if dnat_entry_name and not isinstance(dnat_entry_name, str):
            raise TypeError("Expected argument 'dnat_entry_name' to be a str")
        pulumi.set(__self__, "dnat_entry_name", dnat_entry_name)
        if external_ip and not isinstance(external_ip, str):
            raise TypeError("Expected argument 'external_ip' to be a str")
        pulumi.set(__self__, "external_ip", external_ip)
        if external_port and not isinstance(external_port, str):
            raise TypeError("Expected argument 'external_port' to be a str")
        pulumi.set(__self__, "external_port", external_port)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if internal_ip and not isinstance(internal_ip, str):
            raise TypeError("Expected argument 'internal_ip' to be a str")
        pulumi.set(__self__, "internal_ip", internal_ip)
        if internal_port and not isinstance(internal_port, str):
            raise TypeError("Expected argument 'internal_port' to be a str")
        pulumi.set(__self__, "internal_port", internal_port)
        if nat_gateway_id and not isinstance(nat_gateway_id, str):
            raise TypeError("Expected argument 'nat_gateway_id' to be a str")
        pulumi.set(__self__, "nat_gateway_id", nat_gateway_id)
        if port_type and not isinstance(port_type, str):
            raise TypeError("Expected argument 'port_type' to be a str")
        pulumi.set(__self__, "port_type", port_type)
        if protocol and not isinstance(protocol, str):
            raise TypeError("Expected argument 'protocol' to be a str")
        pulumi.set(__self__, "protocol", protocol)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="dnatEntryId")
    def dnat_entry_id(self) -> builtins.str:
        """
        DNAT规则的ID。
        """
        return pulumi.get(self, "dnat_entry_id")

    @property
    @pulumi.getter(name="dnatEntryName")
    def dnat_entry_name(self) -> builtins.str:
        """
        DNAT规则的名称。
        """
        return pulumi.get(self, "dnat_entry_name")

    @property
    @pulumi.getter(name="externalIp")
    def external_ip(self) -> builtins.str:
        """
        NAT网关用于网络地址转换的IP地址。当NAT网关为公网NAT网关时，传入其绑定的公网IP地址。当NAT网关为私网NAT网关时，传入其中转IP地址。
        """
        return pulumi.get(self, "external_ip")

    @property
    @pulumi.getter(name="externalPort")
    def external_port(self) -> builtins.str:
        """
        接收来自公网外部请求的端口或端口段。
        """
        return pulumi.get(self, "external_port")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="internalIp")
    def internal_ip(self) -> builtins.str:
        """
        云服务器实例的私网IP。
        """
        return pulumi.get(self, "internal_ip")

    @property
    @pulumi.getter(name="internalPort")
    def internal_port(self) -> builtins.str:
        """
        云服务器实例私网IP的端口或端口段。
        """
        return pulumi.get(self, "internal_port")

    @property
    @pulumi.getter(name="natGatewayId")
    def nat_gateway_id(self) -> builtins.str:
        """
        DNAT规则所属NAT网关的ID。
        """
        return pulumi.get(self, "nat_gateway_id")

    @property
    @pulumi.getter(name="portType")
    def port_type(self) -> builtins.str:
        """
        DNAT规则的端口类型。specified：指定端口。any：任意端口。即IP映射。
        """
        return pulumi.get(self, "port_type")

    @property
    @pulumi.getter
    def protocol(self) -> builtins.str:
        """
        协议类型。tcp：转发TCP协议的报文。udp：转发UDP协议的报文。
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        DNAT规则的状态。Creating：创建中。Deleting：删除中。Available：可用。
        """
        return pulumi.get(self, "status")


class AwaitableGetDnatentryResult(GetDnatentryResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDnatentryResult(
            dnat_entry_id=self.dnat_entry_id,
            dnat_entry_name=self.dnat_entry_name,
            external_ip=self.external_ip,
            external_port=self.external_port,
            id=self.id,
            internal_ip=self.internal_ip,
            internal_port=self.internal_port,
            nat_gateway_id=self.nat_gateway_id,
            port_type=self.port_type,
            protocol=self.protocol,
            status=self.status)


def get_dnatentry(id: Optional[builtins.str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDnatentryResult:
    """
    Data Source schema for Byteplus::NatGateway::Dnatentry


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:natgateway/getDnatentry:getDnatentry', __args__, opts=opts, typ=GetDnatentryResult).value

    return AwaitableGetDnatentryResult(
        dnat_entry_id=pulumi.get(__ret__, 'dnat_entry_id'),
        dnat_entry_name=pulumi.get(__ret__, 'dnat_entry_name'),
        external_ip=pulumi.get(__ret__, 'external_ip'),
        external_port=pulumi.get(__ret__, 'external_port'),
        id=pulumi.get(__ret__, 'id'),
        internal_ip=pulumi.get(__ret__, 'internal_ip'),
        internal_port=pulumi.get(__ret__, 'internal_port'),
        nat_gateway_id=pulumi.get(__ret__, 'nat_gateway_id'),
        port_type=pulumi.get(__ret__, 'port_type'),
        protocol=pulumi.get(__ret__, 'protocol'),
        status=pulumi.get(__ret__, 'status'))
def get_dnatentry_output(id: Optional[pulumi.Input[builtins.str]] = None,
                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDnatentryResult]:
    """
    Data Source schema for Byteplus::NatGateway::Dnatentry


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:natgateway/getDnatentry:getDnatentry', __args__, opts=opts, typ=GetDnatentryResult)
    return __ret__.apply(lambda __response__: GetDnatentryResult(
        dnat_entry_id=pulumi.get(__response__, 'dnat_entry_id'),
        dnat_entry_name=pulumi.get(__response__, 'dnat_entry_name'),
        external_ip=pulumi.get(__response__, 'external_ip'),
        external_port=pulumi.get(__response__, 'external_port'),
        id=pulumi.get(__response__, 'id'),
        internal_ip=pulumi.get(__response__, 'internal_ip'),
        internal_port=pulumi.get(__response__, 'internal_port'),
        nat_gateway_id=pulumi.get(__response__, 'nat_gateway_id'),
        port_type=pulumi.get(__response__, 'port_type'),
        protocol=pulumi.get(__response__, 'protocol'),
        status=pulumi.get(__response__, 'status')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetListenerResult',
    'AwaitableGetListenerResult',
    'get_listener',
    'get_listener_output',
]

@pulumi.output_type
class GetListenerResult:
    """
    A collection of values returned by getListener.
    """
    def __init__(__self__, acl_ids=None, acl_status=None, acl_type=None, bandwidth=None, ca_certificate_id=None, ca_enabled=None, cert_center_certificate_id=None, certificate_id=None, certificate_source=None, client_body_timeout=None, client_header_timeout=None, connection_drain_enabled=None, connection_drain_timeout=None, cookie=None, cps=None, created_time=None, description=None, enabled=None, end_port=None, established_timeout=None, health_check=None, http2_enabled=None, id=None, keepalive_timeout=None, listener_id=None, listener_name=None, load_balancer_id=None, max_connections=None, persistence_timeout=None, persistence_type=None, port=None, protocol=None, proxy_connect_timeout=None, proxy_protocol_type=None, proxy_read_timeout=None, proxy_send_timeout=None, scheduler=None, security_policy_id=None, send_timeout=None, server_group_id=None, start_port=None, status=None, tags=None, updated_time=None, waf_protection_enabled=None):
        if acl_ids and not isinstance(acl_ids, list):
            raise TypeError("Expected argument 'acl_ids' to be a list")
        pulumi.set(__self__, "acl_ids", acl_ids)
        if acl_status and not isinstance(acl_status, str):
            raise TypeError("Expected argument 'acl_status' to be a str")
        pulumi.set(__self__, "acl_status", acl_status)
        if acl_type and not isinstance(acl_type, str):
            raise TypeError("Expected argument 'acl_type' to be a str")
        pulumi.set(__self__, "acl_type", acl_type)
        if bandwidth and not isinstance(bandwidth, int):
            raise TypeError("Expected argument 'bandwidth' to be a int")
        pulumi.set(__self__, "bandwidth", bandwidth)
        if ca_certificate_id and not isinstance(ca_certificate_id, str):
            raise TypeError("Expected argument 'ca_certificate_id' to be a str")
        pulumi.set(__self__, "ca_certificate_id", ca_certificate_id)
        if ca_enabled and not isinstance(ca_enabled, str):
            raise TypeError("Expected argument 'ca_enabled' to be a str")
        pulumi.set(__self__, "ca_enabled", ca_enabled)
        if cert_center_certificate_id and not isinstance(cert_center_certificate_id, str):
            raise TypeError("Expected argument 'cert_center_certificate_id' to be a str")
        pulumi.set(__self__, "cert_center_certificate_id", cert_center_certificate_id)
        if certificate_id and not isinstance(certificate_id, str):
            raise TypeError("Expected argument 'certificate_id' to be a str")
        pulumi.set(__self__, "certificate_id", certificate_id)
        if certificate_source and not isinstance(certificate_source, str):
            raise TypeError("Expected argument 'certificate_source' to be a str")
        pulumi.set(__self__, "certificate_source", certificate_source)
        if client_body_timeout and not isinstance(client_body_timeout, int):
            raise TypeError("Expected argument 'client_body_timeout' to be a int")
        pulumi.set(__self__, "client_body_timeout", client_body_timeout)
        if client_header_timeout and not isinstance(client_header_timeout, int):
            raise TypeError("Expected argument 'client_header_timeout' to be a int")
        pulumi.set(__self__, "client_header_timeout", client_header_timeout)
        if connection_drain_enabled and not isinstance(connection_drain_enabled, str):
            raise TypeError("Expected argument 'connection_drain_enabled' to be a str")
        pulumi.set(__self__, "connection_drain_enabled", connection_drain_enabled)
        if connection_drain_timeout and not isinstance(connection_drain_timeout, int):
            raise TypeError("Expected argument 'connection_drain_timeout' to be a int")
        pulumi.set(__self__, "connection_drain_timeout", connection_drain_timeout)
        if cookie and not isinstance(cookie, str):
            raise TypeError("Expected argument 'cookie' to be a str")
        pulumi.set(__self__, "cookie", cookie)
        if cps and not isinstance(cps, int):
            raise TypeError("Expected argument 'cps' to be a int")
        pulumi.set(__self__, "cps", cps)
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if enabled and not isinstance(enabled, str):
            raise TypeError("Expected argument 'enabled' to be a str")
        pulumi.set(__self__, "enabled", enabled)
        if end_port and not isinstance(end_port, int):
            raise TypeError("Expected argument 'end_port' to be a int")
        pulumi.set(__self__, "end_port", end_port)
        if established_timeout and not isinstance(established_timeout, int):
            raise TypeError("Expected argument 'established_timeout' to be a int")
        pulumi.set(__self__, "established_timeout", established_timeout)
        if health_check and not isinstance(health_check, dict):
            raise TypeError("Expected argument 'health_check' to be a dict")
        pulumi.set(__self__, "health_check", health_check)
        if http2_enabled and not isinstance(http2_enabled, str):
            raise TypeError("Expected argument 'http2_enabled' to be a str")
        pulumi.set(__self__, "http2_enabled", http2_enabled)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if keepalive_timeout and not isinstance(keepalive_timeout, int):
            raise TypeError("Expected argument 'keepalive_timeout' to be a int")
        pulumi.set(__self__, "keepalive_timeout", keepalive_timeout)
        if listener_id and not isinstance(listener_id, str):
            raise TypeError("Expected argument 'listener_id' to be a str")
        pulumi.set(__self__, "listener_id", listener_id)
        if listener_name and not isinstance(listener_name, str):
            raise TypeError("Expected argument 'listener_name' to be a str")
        pulumi.set(__self__, "listener_name", listener_name)
        if load_balancer_id and not isinstance(load_balancer_id, str):
            raise TypeError("Expected argument 'load_balancer_id' to be a str")
        pulumi.set(__self__, "load_balancer_id", load_balancer_id)
        if max_connections and not isinstance(max_connections, int):
            raise TypeError("Expected argument 'max_connections' to be a int")
        pulumi.set(__self__, "max_connections", max_connections)
        if persistence_timeout and not isinstance(persistence_timeout, int):
            raise TypeError("Expected argument 'persistence_timeout' to be a int")
        pulumi.set(__self__, "persistence_timeout", persistence_timeout)
        if persistence_type and not isinstance(persistence_type, str):
            raise TypeError("Expected argument 'persistence_type' to be a str")
        pulumi.set(__self__, "persistence_type", persistence_type)
        if port and not isinstance(port, int):
            raise TypeError("Expected argument 'port' to be a int")
        pulumi.set(__self__, "port", port)
        if protocol and not isinstance(protocol, str):
            raise TypeError("Expected argument 'protocol' to be a str")
        pulumi.set(__self__, "protocol", protocol)
        if proxy_connect_timeout and not isinstance(proxy_connect_timeout, int):
            raise TypeError("Expected argument 'proxy_connect_timeout' to be a int")
        pulumi.set(__self__, "proxy_connect_timeout", proxy_connect_timeout)
        if proxy_protocol_type and not isinstance(proxy_protocol_type, str):
            raise TypeError("Expected argument 'proxy_protocol_type' to be a str")
        pulumi.set(__self__, "proxy_protocol_type", proxy_protocol_type)
        if proxy_read_timeout and not isinstance(proxy_read_timeout, int):
            raise TypeError("Expected argument 'proxy_read_timeout' to be a int")
        pulumi.set(__self__, "proxy_read_timeout", proxy_read_timeout)
        if proxy_send_timeout and not isinstance(proxy_send_timeout, int):
            raise TypeError("Expected argument 'proxy_send_timeout' to be a int")
        pulumi.set(__self__, "proxy_send_timeout", proxy_send_timeout)
        if scheduler and not isinstance(scheduler, str):
            raise TypeError("Expected argument 'scheduler' to be a str")
        pulumi.set(__self__, "scheduler", scheduler)
        if security_policy_id and not isinstance(security_policy_id, str):
            raise TypeError("Expected argument 'security_policy_id' to be a str")
        pulumi.set(__self__, "security_policy_id", security_policy_id)
        if send_timeout and not isinstance(send_timeout, int):
            raise TypeError("Expected argument 'send_timeout' to be a int")
        pulumi.set(__self__, "send_timeout", send_timeout)
        if server_group_id and not isinstance(server_group_id, str):
            raise TypeError("Expected argument 'server_group_id' to be a str")
        pulumi.set(__self__, "server_group_id", server_group_id)
        if start_port and not isinstance(start_port, int):
            raise TypeError("Expected argument 'start_port' to be a int")
        pulumi.set(__self__, "start_port", start_port)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)
        if waf_protection_enabled and not isinstance(waf_protection_enabled, str):
            raise TypeError("Expected argument 'waf_protection_enabled' to be a str")
        pulumi.set(__self__, "waf_protection_enabled", waf_protection_enabled)

    @property
    @pulumi.getter(name="aclIds")
    def acl_ids(self) -> Sequence[builtins.str]:
        """
        监听器绑定的访问控制策略组ID。仅AclStatus参数为on时返回。
        """
        return pulumi.get(self, "acl_ids")

    @property
    @pulumi.getter(name="aclStatus")
    def acl_status(self) -> builtins.str:
        """
        是否开启访问控制功能。取值如下：on：开启。off（默认值）：不开启。
        """
        return pulumi.get(self, "acl_status")

    @property
    @pulumi.getter(name="aclType")
    def acl_type(self) -> builtins.str:
        """
        访问控制的方式。white：白名单。black：黑名单。仅AclStatus参数为on时，本参数有效。
        """
        return pulumi.get(self, "acl_type")

    @property
    @pulumi.getter
    def bandwidth(self) -> builtins.int:
        """
        监听器的带宽上限，即此监听器独占CLB实例的带宽，单位为Mbps。-1（默认值）：此监听器不独占CLB的带，与其他监听器共享CLB实例未被独占的带宽。取值范围：1～CLB实例未被独占的带宽。
        """
        return pulumi.get(self, "bandwidth")

    @property
    @pulumi.getter(name="caCertificateId")
    def ca_certificate_id(self) -> builtins.str:
        """
        双向认证的CA证书。
        """
        return pulumi.get(self, "ca_certificate_id")

    @property
    @pulumi.getter(name="caEnabled")
    def ca_enabled(self) -> builtins.str:
        """
        是否开启双向认证。on：开启。off（默认值）：不开启。
        """
        return pulumi.get(self, "ca_enabled")

    @property
    @pulumi.getter(name="certCenterCertificateId")
    def cert_center_certificate_id(self) -> builtins.str:
        """
        证书中心的证书的ID。
        """
        return pulumi.get(self, "cert_center_certificate_id")

    @property
    @pulumi.getter(name="certificateId")
    def certificate_id(self) -> builtins.str:
        """
        CLB侧证书管理模块的证书的ID。
        """
        return pulumi.get(self, "certificate_id")

    @property
    @pulumi.getter(name="certificateSource")
    def certificate_source(self) -> builtins.str:
        """
        证书的来源。clb (默认)：CLB上传的证书。cert_center：证书中心上传的证书。user：用户上传的证书。
        """
        return pulumi.get(self, "certificate_source")

    @property
    @pulumi.getter(name="clientBodyTimeout")
    def client_body_timeout(self) -> builtins.int:
        """
        读取客户端请求正文的超时时间。此超时时间仅针对两个连续的读操作之间设置，而非整个请求的传输过程。取值范围为 30-120秒，默认为60秒。仅参数Protocol取HTTP或HTTPS时，本参数有效
        """
        return pulumi.get(self, "client_body_timeout")

    @property
    @pulumi.getter(name="clientHeaderTimeout")
    def client_header_timeout(self) -> builtins.int:
        """
        读取客户端请求头的超时时间。取值范围为30-120秒。默认为60秒。仅参数Protocol取HTTP或HTTPS时，本参数有效。
        """
        return pulumi.get(self, "client_header_timeout")

    @property
    @pulumi.getter(name="connectionDrainEnabled")
    def connection_drain_enabled(self) -> builtins.str:
        """
        监听器是否开启连接优雅中断功能。on：开启。off：不开启。参数Protocol返回为HTTP或HTTPS时，该参数固定返回off。
        """
        return pulumi.get(self, "connection_drain_enabled")

    @property
    @pulumi.getter(name="connectionDrainTimeout")
    def connection_drain_timeout(self) -> builtins.int:
        """
        连接优雅中断的超时时间，单位为秒。参数ConnectionDrainEnabled返回为off时，该参数返回0。
        """
        return pulumi.get(self, "connection_drain_timeout")

    @property
    @pulumi.getter
    def cookie(self) -> builtins.str:
        """
        后端服务器配置的会话保持的Cookie名称。仅参数PersistenceType取server时，本参数有效且必填。只能包含字母、数字、下划线（_）和中划线（-）。长度限制在1～200字符之间。
        """
        return pulumi.get(self, "cookie")

    @property
    @pulumi.getter
    def cps(self) -> builtins.int:
        """
        每秒新建连接数的上限。-1（默认值）：不限制，即CLB实例的新建连接数上限。取值范围：1～CLB实例的新连接数上限。
        """
        return pulumi.get(self, "cps")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        监听器的创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        监听器的描述。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：英文逗号（,）、点（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ～ 255个字符。不填则默认值为空字符串。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def enabled(self) -> builtins.str:
        """
        是否启用监听器。on（默认值）：开启。off：不开启。
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter(name="endPort")
    def end_port(self) -> builtins.int:
        """
        全端口监听的结束端口，取值范围为1-65535。参数Port为“0”时，该参数必须传入，且该参数取值应大于tartPort。
        """
        return pulumi.get(self, "end_port")

    @property
    @pulumi.getter(name="establishedTimeout")
    def established_timeout(self) -> builtins.int:
        """
        监听器的连接超时时间。仅参数Protocol取TCP或UDP时，本参数有效。取值如下：TCP协议：10-900秒，默认为900秒。UDP协议：1-300秒，默认为90秒。
        """
        return pulumi.get(self, "established_timeout")

    @property
    @pulumi.getter(name="healthCheck")
    def health_check(self) -> 'outputs.GetListenerHealthCheckResult':
        """
        健康检查相关信息。
        """
        return pulumi.get(self, "health_check")

    @property
    @pulumi.getter(name="http2Enabled")
    def http2_enabled(self) -> builtins.str:
        """
        监听器是否开启前端HTTP 2.0协议。仅参数`Protocol取HTTPS时，本参数有效。取值如下：|on：开启。off（默认值）：不开启。
        """
        return pulumi.get(self, "http2_enabled")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="keepaliveTimeout")
    def keepalive_timeout(self) -> builtins.int:
        """
        客户端与CLB之间的长连接超时时间。取值范围为 0-900秒，默认为75秒。0表示禁用长连接。仅参数Protocol取HTTP或HTTPS时，本参数有效。
        """
        return pulumi.get(self, "keepalive_timeout")

    @property
    @pulumi.getter(name="listenerId")
    def listener_id(self) -> builtins.str:
        """
        监听器的ID。
        """
        return pulumi.get(self, "listener_id")

    @property
    @pulumi.getter(name="listenerName")
    def listener_name(self) -> builtins.str:
        """
        监听器的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线_）和中划线（-）。长度限制在1～128字符之间。不填则默认将“协议-端口”作为监听器名称。
        """
        return pulumi.get(self, "listener_name")

    @property
    @pulumi.getter(name="loadBalancerId")
    def load_balancer_id(self) -> builtins.str:
        """
        CLB实例的ID。
        """
        return pulumi.get(self, "load_balancer_id")

    @property
    @pulumi.getter(name="maxConnections")
    def max_connections(self) -> builtins.int:
        """
        最大并发连接数的上限。-1（默认值）：不限制，CLB实例的最大并发连接数上限。取值范围：1～CLB实例的最大并发连接数上限。
        """
        return pulumi.get(self, "max_connections")

    @property
    @pulumi.getter(name="persistenceTimeout")
    def persistence_timeout(self) -> builtins.int:
        """
        会话保持的超时时间，单位为秒。取值范围根据参数PersistenceType取值有所不同。PersistenceType置为source_ip时，取值范围为1～3600。PersistenceType配置为insert时，取值范围为1～86400。
        """
        return pulumi.get(self, "persistence_timeout")

    @property
    @pulumi.getter(name="persistenceType")
    def persistence_type(self) -> builtins.str:
        """
        会话保持的类型。取值如下：off（默认值）：不启用会话保持。source_ip：源地址IP，仅参数ProtocolTCP或UDP时，本取值有效。insert：植入Cookie，仅参数Protocol取HTTP或HTTPS且Scheduler取wrr时，本取值生效。server：重写Cookie，仅参数Protocol取HTTP或HTTPS且Scheduler取wrr时，本取值生效。。
        """
        return pulumi.get(self, "persistence_type")

    @property
    @pulumi.getter
    def port(self) -> builtins.int:
        """
        监听器接收请求使用的端口。取值范围为 0～65535。参数Protocol为“TCP”或“UDP”时，支持传入0，表示用全端口监听。
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter
    def protocol(self) -> builtins.str:
        """
        监听器的协议。
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter(name="proxyConnectTimeout")
    def proxy_connect_timeout(self) -> builtins.int:
        """
        CLB与后端服务器之间的连接建立超时时间。建议大于健康检查超时时间。取值范围为 4-120秒，默认为4。仅参数Protocol取HTTP或HTTPS时，本参数有效。
        """
        return pulumi.get(self, "proxy_connect_timeout")

    @property
    @pulumi.getter(name="proxyProtocolType")
    def proxy_protocol_type(self) -> builtins.str:
        """
        是否启用Proxy-Protocol协议。仅参数Protocol取TCP或UDP时，本参数有效。取值如下：off（默认值）：关闭。standard：开启。
        """
        return pulumi.get(self, "proxy_protocol_type")

    @property
    @pulumi.getter(name="proxyReadTimeout")
    def proxy_read_timeout(self) -> builtins.int:
        """
        CLB从后端服务器读取响应的超时时间。此超时时间仅针对两个连续的读操作之间设置，而非整个响应的传输过程。取值范围为30-3600秒，默认为60秒。仅参数Protocol取HTTP或HTTPS时，本参数有效。
        """
        return pulumi.get(self, "proxy_read_timeout")

    @property
    @pulumi.getter(name="proxySendTimeout")
    def proxy_send_timeout(self) -> builtins.int:
        """
        CLB将请求传输到后端服务器的超时时间。此超时仅针对两个连续的写操作之间设置，而非整个请求的传输过程。取值范围为30-3600秒，默认为60秒。仅参数Protocol取HTTP或HTTPS时，本参数有效。
        """
        return pulumi.get(self, "proxy_send_timeout")

    @property
    @pulumi.getter
    def scheduler(self) -> builtins.str:
        """
        监听器使用的调度算法。wrr（默认值）：加权轮询。wlc：加权最小连接数。sh：源地址哈希。
        """
        return pulumi.get(self, "scheduler")

    @property
    @pulumi.getter(name="securityPolicyId")
    def security_policy_id(self) -> builtins.str:
        """
        HTTPS监听器的TLS安全策略。仅参数Protocol取HTTPS时，本参数有效。 取值如下：default*policy（默认值）：支持SSL v3、TLS v1.0、TLS v1.1、TLS v1.2。tls*cipher*policy*1*0：支持TLS v1.0、TLS v1.1、TLS v1.2。tls*cipher*policy*1*1：支持TLS v1.1、TLS v1.2。tls*cipher*policy*1*2：支持TLS v1.2。tls*cipher*policy*1*2*strict：支持TLS v1.2。
        """
        return pulumi.get(self, "security_policy_id")

    @property
    @pulumi.getter(name="sendTimeout")
    def send_timeout(self) -> builtins.int:
        """
        CLB向客户端发送响应的超时时间。此超时仅针对两个连续的写操作之间设置，而非整响应的传输过程。取值范围为 1-3600秒，默认为60秒。仅参数Protocol取HTTP或HTTPS时，本参数有效。
        """
        return pulumi.get(self, "send_timeout")

    @property
    @pulumi.getter(name="serverGroupId")
    def server_group_id(self) -> builtins.str:
        """
        监听器关联的后端服务器组 ID。
        """
        return pulumi.get(self, "server_group_id")

    @property
    @pulumi.getter(name="startPort")
    def start_port(self) -> builtins.int:
        """
        全端口监听的起始端口，取值范围为1-65535。参数Port为“0”时，该参数必须传入。
        """
        return pulumi.get(self, "start_port")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        监听器的状态。Creating：创建中。Active：运行中。Deleting: 删除中。Disabled: 已停用。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetListenerTagResult']:
        """
        监听器所属标签。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        监听器最近一次的操作时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="wafProtectionEnabled")
    def waf_protection_enabled(self) -> builtins.str:
        """
        是否将经过七层监听器的流量送至Web应用防火墙进行检测和过滤。on：是。off：否。
        """
        return pulumi.get(self, "waf_protection_enabled")


class AwaitableGetListenerResult(GetListenerResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetListenerResult(
            acl_ids=self.acl_ids,
            acl_status=self.acl_status,
            acl_type=self.acl_type,
            bandwidth=self.bandwidth,
            ca_certificate_id=self.ca_certificate_id,
            ca_enabled=self.ca_enabled,
            cert_center_certificate_id=self.cert_center_certificate_id,
            certificate_id=self.certificate_id,
            certificate_source=self.certificate_source,
            client_body_timeout=self.client_body_timeout,
            client_header_timeout=self.client_header_timeout,
            connection_drain_enabled=self.connection_drain_enabled,
            connection_drain_timeout=self.connection_drain_timeout,
            cookie=self.cookie,
            cps=self.cps,
            created_time=self.created_time,
            description=self.description,
            enabled=self.enabled,
            end_port=self.end_port,
            established_timeout=self.established_timeout,
            health_check=self.health_check,
            http2_enabled=self.http2_enabled,
            id=self.id,
            keepalive_timeout=self.keepalive_timeout,
            listener_id=self.listener_id,
            listener_name=self.listener_name,
            load_balancer_id=self.load_balancer_id,
            max_connections=self.max_connections,
            persistence_timeout=self.persistence_timeout,
            persistence_type=self.persistence_type,
            port=self.port,
            protocol=self.protocol,
            proxy_connect_timeout=self.proxy_connect_timeout,
            proxy_protocol_type=self.proxy_protocol_type,
            proxy_read_timeout=self.proxy_read_timeout,
            proxy_send_timeout=self.proxy_send_timeout,
            scheduler=self.scheduler,
            security_policy_id=self.security_policy_id,
            send_timeout=self.send_timeout,
            server_group_id=self.server_group_id,
            start_port=self.start_port,
            status=self.status,
            tags=self.tags,
            updated_time=self.updated_time,
            waf_protection_enabled=self.waf_protection_enabled)


def get_listener(id: Optional[builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetListenerResult:
    """
    Data Source schema for Byteplus::CLB::Listener


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:clb/getListener:getListener', __args__, opts=opts, typ=GetListenerResult).value

    return AwaitableGetListenerResult(
        acl_ids=pulumi.get(__ret__, 'acl_ids'),
        acl_status=pulumi.get(__ret__, 'acl_status'),
        acl_type=pulumi.get(__ret__, 'acl_type'),
        bandwidth=pulumi.get(__ret__, 'bandwidth'),
        ca_certificate_id=pulumi.get(__ret__, 'ca_certificate_id'),
        ca_enabled=pulumi.get(__ret__, 'ca_enabled'),
        cert_center_certificate_id=pulumi.get(__ret__, 'cert_center_certificate_id'),
        certificate_id=pulumi.get(__ret__, 'certificate_id'),
        certificate_source=pulumi.get(__ret__, 'certificate_source'),
        client_body_timeout=pulumi.get(__ret__, 'client_body_timeout'),
        client_header_timeout=pulumi.get(__ret__, 'client_header_timeout'),
        connection_drain_enabled=pulumi.get(__ret__, 'connection_drain_enabled'),
        connection_drain_timeout=pulumi.get(__ret__, 'connection_drain_timeout'),
        cookie=pulumi.get(__ret__, 'cookie'),
        cps=pulumi.get(__ret__, 'cps'),
        created_time=pulumi.get(__ret__, 'created_time'),
        description=pulumi.get(__ret__, 'description'),
        enabled=pulumi.get(__ret__, 'enabled'),
        end_port=pulumi.get(__ret__, 'end_port'),
        established_timeout=pulumi.get(__ret__, 'established_timeout'),
        health_check=pulumi.get(__ret__, 'health_check'),
        http2_enabled=pulumi.get(__ret__, 'http2_enabled'),
        id=pulumi.get(__ret__, 'id'),
        keepalive_timeout=pulumi.get(__ret__, 'keepalive_timeout'),
        listener_id=pulumi.get(__ret__, 'listener_id'),
        listener_name=pulumi.get(__ret__, 'listener_name'),
        load_balancer_id=pulumi.get(__ret__, 'load_balancer_id'),
        max_connections=pulumi.get(__ret__, 'max_connections'),
        persistence_timeout=pulumi.get(__ret__, 'persistence_timeout'),
        persistence_type=pulumi.get(__ret__, 'persistence_type'),
        port=pulumi.get(__ret__, 'port'),
        protocol=pulumi.get(__ret__, 'protocol'),
        proxy_connect_timeout=pulumi.get(__ret__, 'proxy_connect_timeout'),
        proxy_protocol_type=pulumi.get(__ret__, 'proxy_protocol_type'),
        proxy_read_timeout=pulumi.get(__ret__, 'proxy_read_timeout'),
        proxy_send_timeout=pulumi.get(__ret__, 'proxy_send_timeout'),
        scheduler=pulumi.get(__ret__, 'scheduler'),
        security_policy_id=pulumi.get(__ret__, 'security_policy_id'),
        send_timeout=pulumi.get(__ret__, 'send_timeout'),
        server_group_id=pulumi.get(__ret__, 'server_group_id'),
        start_port=pulumi.get(__ret__, 'start_port'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        updated_time=pulumi.get(__ret__, 'updated_time'),
        waf_protection_enabled=pulumi.get(__ret__, 'waf_protection_enabled'))
def get_listener_output(id: Optional[pulumi.Input[builtins.str]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetListenerResult]:
    """
    Data Source schema for Byteplus::CLB::Listener


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:clb/getListener:getListener', __args__, opts=opts, typ=GetListenerResult)
    return __ret__.apply(lambda __response__: GetListenerResult(
        acl_ids=pulumi.get(__response__, 'acl_ids'),
        acl_status=pulumi.get(__response__, 'acl_status'),
        acl_type=pulumi.get(__response__, 'acl_type'),
        bandwidth=pulumi.get(__response__, 'bandwidth'),
        ca_certificate_id=pulumi.get(__response__, 'ca_certificate_id'),
        ca_enabled=pulumi.get(__response__, 'ca_enabled'),
        cert_center_certificate_id=pulumi.get(__response__, 'cert_center_certificate_id'),
        certificate_id=pulumi.get(__response__, 'certificate_id'),
        certificate_source=pulumi.get(__response__, 'certificate_source'),
        client_body_timeout=pulumi.get(__response__, 'client_body_timeout'),
        client_header_timeout=pulumi.get(__response__, 'client_header_timeout'),
        connection_drain_enabled=pulumi.get(__response__, 'connection_drain_enabled'),
        connection_drain_timeout=pulumi.get(__response__, 'connection_drain_timeout'),
        cookie=pulumi.get(__response__, 'cookie'),
        cps=pulumi.get(__response__, 'cps'),
        created_time=pulumi.get(__response__, 'created_time'),
        description=pulumi.get(__response__, 'description'),
        enabled=pulumi.get(__response__, 'enabled'),
        end_port=pulumi.get(__response__, 'end_port'),
        established_timeout=pulumi.get(__response__, 'established_timeout'),
        health_check=pulumi.get(__response__, 'health_check'),
        http2_enabled=pulumi.get(__response__, 'http2_enabled'),
        id=pulumi.get(__response__, 'id'),
        keepalive_timeout=pulumi.get(__response__, 'keepalive_timeout'),
        listener_id=pulumi.get(__response__, 'listener_id'),
        listener_name=pulumi.get(__response__, 'listener_name'),
        load_balancer_id=pulumi.get(__response__, 'load_balancer_id'),
        max_connections=pulumi.get(__response__, 'max_connections'),
        persistence_timeout=pulumi.get(__response__, 'persistence_timeout'),
        persistence_type=pulumi.get(__response__, 'persistence_type'),
        port=pulumi.get(__response__, 'port'),
        protocol=pulumi.get(__response__, 'protocol'),
        proxy_connect_timeout=pulumi.get(__response__, 'proxy_connect_timeout'),
        proxy_protocol_type=pulumi.get(__response__, 'proxy_protocol_type'),
        proxy_read_timeout=pulumi.get(__response__, 'proxy_read_timeout'),
        proxy_send_timeout=pulumi.get(__response__, 'proxy_send_timeout'),
        scheduler=pulumi.get(__response__, 'scheduler'),
        security_policy_id=pulumi.get(__response__, 'security_policy_id'),
        send_timeout=pulumi.get(__response__, 'send_timeout'),
        server_group_id=pulumi.get(__response__, 'server_group_id'),
        start_port=pulumi.get(__response__, 'start_port'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        updated_time=pulumi.get(__response__, 'updated_time'),
        waf_protection_enabled=pulumi.get(__response__, 'waf_protection_enabled')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'TopicAccessPolicy',
    'TopicTag',
    'GetTopicAccessPolicyResult',
    'GetTopicTagResult',
]

@pulumi.output_type
class TopicAccessPolicy(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "accessPolicy":
            suggest = "access_policy"
        elif key == "userName":
            suggest = "user_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in TopicAccessPolicy. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        TopicAccessPolicy.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        TopicAccessPolicy.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 access_policy: Optional[builtins.str] = None,
                 user_name: Optional[builtins.str] = None):
        """
        :param builtins.str access_policy: SASL 用户对于当前 Topic 的访问权限。PubSub：拥有发布、订阅权限。Pub：拥有发布权限。Sub：拥有订阅权限。
        :param builtins.str user_name: SASL 用户名称。
        """
        if access_policy is not None:
            pulumi.set(__self__, "access_policy", access_policy)
        if user_name is not None:
            pulumi.set(__self__, "user_name", user_name)

    @property
    @pulumi.getter(name="accessPolicy")
    def access_policy(self) -> Optional[builtins.str]:
        """
        SASL 用户对于当前 Topic 的访问权限。PubSub：拥有发布、订阅权限。Pub：拥有发布权限。Sub：拥有订阅权限。
        """
        return pulumi.get(self, "access_policy")

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> Optional[builtins.str]:
        """
        SASL 用户名称。
        """
        return pulumi.get(self, "user_name")


@pulumi.output_type
class TopicTag(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: 标签键。
        :param builtins.str value: 标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetTopicAccessPolicyResult(dict):
    def __init__(__self__, *,
                 access_policy: builtins.str,
                 user_name: builtins.str):
        """
        :param builtins.str access_policy: SASL 用户对于当前 Topic 的访问权限。PubSub：拥有发布、订阅权限。Pub：拥有发布权限。Sub：拥有订阅权限。
        :param builtins.str user_name: SASL 用户名称。
        """
        pulumi.set(__self__, "access_policy", access_policy)
        pulumi.set(__self__, "user_name", user_name)

    @property
    @pulumi.getter(name="accessPolicy")
    def access_policy(self) -> builtins.str:
        """
        SASL 用户对于当前 Topic 的访问权限。PubSub：拥有发布、订阅权限。Pub：拥有发布权限。Sub：拥有订阅权限。
        """
        return pulumi.get(self, "access_policy")

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> builtins.str:
        """
        SASL 用户名称。
        """
        return pulumi.get(self, "user_name")


@pulumi.output_type
class GetTopicTagResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: 标签键。
        :param builtins.str value: 标签值。
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        标签值。
        """
        return pulumi.get(self, "value")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetDnsControlPolicyResult',
    'AwaitableGetDnsControlPolicyResult',
    'get_dns_control_policy',
    'get_dns_control_policy_output',
]

@pulumi.output_type
class GetDnsControlPolicyResult:
    """
    A collection of values returned by getDnsControlPolicy.
    """
    def __init__(__self__, account_id=None, description=None, destination=None, destination_group_lists=None, destination_type=None, domain_list_v1s=None, domain_lists=None, hit_cnt=None, id=None, internet_firewall_id=None, last_hit_time=None, rule_id=None, sources=None, status=None, use_count=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if destination and not isinstance(destination, str):
            raise TypeError("Expected argument 'destination' to be a str")
        pulumi.set(__self__, "destination", destination)
        if destination_group_lists and not isinstance(destination_group_lists, list):
            raise TypeError("Expected argument 'destination_group_lists' to be a list")
        pulumi.set(__self__, "destination_group_lists", destination_group_lists)
        if destination_type and not isinstance(destination_type, str):
            raise TypeError("Expected argument 'destination_type' to be a str")
        pulumi.set(__self__, "destination_type", destination_type)
        if domain_list_v1s and not isinstance(domain_list_v1s, list):
            raise TypeError("Expected argument 'domain_list_v1s' to be a list")
        pulumi.set(__self__, "domain_list_v1s", domain_list_v1s)
        if domain_lists and not isinstance(domain_lists, list):
            raise TypeError("Expected argument 'domain_lists' to be a list")
        pulumi.set(__self__, "domain_lists", domain_lists)
        if hit_cnt and not isinstance(hit_cnt, int):
            raise TypeError("Expected argument 'hit_cnt' to be a int")
        pulumi.set(__self__, "hit_cnt", hit_cnt)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if internet_firewall_id and not isinstance(internet_firewall_id, str):
            raise TypeError("Expected argument 'internet_firewall_id' to be a str")
        pulumi.set(__self__, "internet_firewall_id", internet_firewall_id)
        if last_hit_time and not isinstance(last_hit_time, int):
            raise TypeError("Expected argument 'last_hit_time' to be a int")
        pulumi.set(__self__, "last_hit_time", last_hit_time)
        if rule_id and not isinstance(rule_id, str):
            raise TypeError("Expected argument 'rule_id' to be a str")
        pulumi.set(__self__, "rule_id", rule_id)
        if sources and not isinstance(sources, list):
            raise TypeError("Expected argument 'sources' to be a list")
        pulumi.set(__self__, "sources", sources)
        if status and not isinstance(status, bool):
            raise TypeError("Expected argument 'status' to be a bool")
        pulumi.set(__self__, "status", status)
        if use_count and not isinstance(use_count, int):
            raise TypeError("Expected argument 'use_count' to be a int")
        pulumi.set(__self__, "use_count", use_count)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> builtins.str:
        """
        用户的唯一标识ID。
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        策略的描述信息。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def destination(self) -> builtins.str:
        """
        访问目的，可以是域名或域名地址簿的唯一标识ID。当前仅支持一个地址簿。
        """
        return pulumi.get(self, "destination")

    @property
    @pulumi.getter(name="destinationGroupLists")
    def destination_group_lists(self) -> Sequence[builtins.str]:
        """
        域名地址簿名称列表。
        """
        return pulumi.get(self, "destination_group_lists")

    @property
    @pulumi.getter(name="destinationType")
    def destination_type(self) -> builtins.str:
        """
        访问目的的类型。domain：域名；group：域名地址簿。
        """
        return pulumi.get(self, "destination_type")

    @property
    @pulumi.getter(name="domainListV1s")
    def domain_list_v1s(self) -> Sequence['outputs.GetDnsControlPolicyDomainListV1Result']:
        """
        域名地址簿的域名列表。
        """
        return pulumi.get(self, "domain_list_v1s")

    @property
    @pulumi.getter(name="domainLists")
    def domain_lists(self) -> Sequence[builtins.str]:
        """
        域名列表。
        """
        return pulumi.get(self, "domain_lists")

    @property
    @pulumi.getter(name="hitCnt")
    def hit_cnt(self) -> builtins.int:
        """
        命中计数，表示该域名黑名单访问控制策略被触发的次数。
        """
        return pulumi.get(self, "hit_cnt")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="internetFirewallId")
    def internet_firewall_id(self) -> builtins.str:
        """
        互联网边界防火墙实例ID。
        """
        return pulumi.get(self, "internet_firewall_id")

    @property
    @pulumi.getter(name="lastHitTime")
    def last_hit_time(self) -> builtins.int:
        """
        最近命中时间戳，表示该域名黑名单访问控制策略最后一次被触发的时间。
        """
        return pulumi.get(self, "last_hit_time")

    @property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> builtins.str:
        """
        访问控制策略的唯一标识ID。
        """
        return pulumi.get(self, "rule_id")

    @property
    @pulumi.getter
    def sources(self) -> Sequence['outputs.GetDnsControlPolicySourceResult']:
        """
        访问源信息，包含VPC列表。
        """
        return pulumi.get(self, "sources")

    @property
    @pulumi.getter
    def status(self) -> builtins.bool:
        """
        域名黑名单访问控制策略的开关状态。false：关闭；true：开启。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="useCount")
    def use_count(self) -> builtins.int:
        """
        该域名黑名单访问控制策略占用的策略数量。
        """
        return pulumi.get(self, "use_count")


class AwaitableGetDnsControlPolicyResult(GetDnsControlPolicyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDnsControlPolicyResult(
            account_id=self.account_id,
            description=self.description,
            destination=self.destination,
            destination_group_lists=self.destination_group_lists,
            destination_type=self.destination_type,
            domain_list_v1s=self.domain_list_v1s,
            domain_lists=self.domain_lists,
            hit_cnt=self.hit_cnt,
            id=self.id,
            internet_firewall_id=self.internet_firewall_id,
            last_hit_time=self.last_hit_time,
            rule_id=self.rule_id,
            sources=self.sources,
            status=self.status,
            use_count=self.use_count)


def get_dns_control_policy(id: Optional[builtins.str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDnsControlPolicyResult:
    """
    Data Source schema for Byteplus::FireWallCenter::DnsControlPolicy


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:firewallcenter/getDnsControlPolicy:getDnsControlPolicy', __args__, opts=opts, typ=GetDnsControlPolicyResult).value

    return AwaitableGetDnsControlPolicyResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        description=pulumi.get(__ret__, 'description'),
        destination=pulumi.get(__ret__, 'destination'),
        destination_group_lists=pulumi.get(__ret__, 'destination_group_lists'),
        destination_type=pulumi.get(__ret__, 'destination_type'),
        domain_list_v1s=pulumi.get(__ret__, 'domain_list_v1s'),
        domain_lists=pulumi.get(__ret__, 'domain_lists'),
        hit_cnt=pulumi.get(__ret__, 'hit_cnt'),
        id=pulumi.get(__ret__, 'id'),
        internet_firewall_id=pulumi.get(__ret__, 'internet_firewall_id'),
        last_hit_time=pulumi.get(__ret__, 'last_hit_time'),
        rule_id=pulumi.get(__ret__, 'rule_id'),
        sources=pulumi.get(__ret__, 'sources'),
        status=pulumi.get(__ret__, 'status'),
        use_count=pulumi.get(__ret__, 'use_count'))
def get_dns_control_policy_output(id: Optional[pulumi.Input[builtins.str]] = None,
                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDnsControlPolicyResult]:
    """
    Data Source schema for Byteplus::FireWallCenter::DnsControlPolicy


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:firewallcenter/getDnsControlPolicy:getDnsControlPolicy', __args__, opts=opts, typ=GetDnsControlPolicyResult)
    return __ret__.apply(lambda __response__: GetDnsControlPolicyResult(
        account_id=pulumi.get(__response__, 'account_id'),
        description=pulumi.get(__response__, 'description'),
        destination=pulumi.get(__response__, 'destination'),
        destination_group_lists=pulumi.get(__response__, 'destination_group_lists'),
        destination_type=pulumi.get(__response__, 'destination_type'),
        domain_list_v1s=pulumi.get(__response__, 'domain_list_v1s'),
        domain_lists=pulumi.get(__response__, 'domain_lists'),
        hit_cnt=pulumi.get(__response__, 'hit_cnt'),
        id=pulumi.get(__response__, 'id'),
        internet_firewall_id=pulumi.get(__response__, 'internet_firewall_id'),
        last_hit_time=pulumi.get(__response__, 'last_hit_time'),
        rule_id=pulumi.get(__response__, 'rule_id'),
        sources=pulumi.get(__response__, 'sources'),
        status=pulumi.get(__response__, 'status'),
        use_count=pulumi.get(__response__, 'use_count')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetNatIpResult',
    'AwaitableGetNatIpResult',
    'get_nat_ip',
    'get_nat_ip_output',
]

@pulumi.output_type
class GetNatIpResult:
    """
    A collection of values returned by getNatIp.
    """
    def __init__(__self__, id=None, is_default=None, nat_gateway_id=None, nat_ip=None, nat_ip_description=None, nat_ip_id=None, nat_ip_name=None, status=None, using_status=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_default and not isinstance(is_default, bool):
            raise TypeError("Expected argument 'is_default' to be a bool")
        pulumi.set(__self__, "is_default", is_default)
        if nat_gateway_id and not isinstance(nat_gateway_id, str):
            raise TypeError("Expected argument 'nat_gateway_id' to be a str")
        pulumi.set(__self__, "nat_gateway_id", nat_gateway_id)
        if nat_ip and not isinstance(nat_ip, str):
            raise TypeError("Expected argument 'nat_ip' to be a str")
        pulumi.set(__self__, "nat_ip", nat_ip)
        if nat_ip_description and not isinstance(nat_ip_description, str):
            raise TypeError("Expected argument 'nat_ip_description' to be a str")
        pulumi.set(__self__, "nat_ip_description", nat_ip_description)
        if nat_ip_id and not isinstance(nat_ip_id, str):
            raise TypeError("Expected argument 'nat_ip_id' to be a str")
        pulumi.set(__self__, "nat_ip_id", nat_ip_id)
        if nat_ip_name and not isinstance(nat_ip_name, str):
            raise TypeError("Expected argument 'nat_ip_name' to be a str")
        pulumi.set(__self__, "nat_ip_name", nat_ip_name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if using_status and not isinstance(using_status, str):
            raise TypeError("Expected argument 'using_status' to be a str")
        pulumi.set(__self__, "using_status", using_status)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> builtins.bool:
        """
        是否为默认中转IP。true：是。false：否。
        """
        return pulumi.get(self, "is_default")

    @property
    @pulumi.getter(name="natGatewayId")
    def nat_gateway_id(self) -> builtins.str:
        """
        私网NAT网关ID。
        """
        return pulumi.get(self, "nat_gateway_id")

    @property
    @pulumi.getter(name="natIp")
    def nat_ip(self) -> builtins.str:
        """
        中转IP的地址。若不填，则系统自动从私网NAT网关所在子网随机分配一个空闲的IP地址。
        """
        return pulumi.get(self, "nat_ip")

    @property
    @pulumi.getter(name="natIpDescription")
    def nat_ip_description(self) -> builtins.str:
        """
        中转IP的描述。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        """
        return pulumi.get(self, "nat_ip_description")

    @property
    @pulumi.getter(name="natIpId")
    def nat_ip_id(self) -> builtins.str:
        """
        中转IP的ID。
        """
        return pulumi.get(self, "nat_ip_id")

    @property
    @pulumi.getter(name="natIpName")
    def nat_ip_name(self) -> builtins.str:
        """
        中转IP的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。不填默认为中转IP的ID。
        """
        return pulumi.get(self, "nat_ip_name")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        中转IP的状态。Creating：创建中。Available：可用。Deleting：删除中。Deleted：已删除。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="usingStatus")
    def using_status(self) -> builtins.str:
        """
        中转IP的使用状态。Idle：未使用。UsedBySnat：被SNAT规则使用。UsedByDnat：被DNAT规则使用。UsedByNat：被SNAT/DNAT规则同时使用。
        """
        return pulumi.get(self, "using_status")


class AwaitableGetNatIpResult(GetNatIpResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNatIpResult(
            id=self.id,
            is_default=self.is_default,
            nat_gateway_id=self.nat_gateway_id,
            nat_ip=self.nat_ip,
            nat_ip_description=self.nat_ip_description,
            nat_ip_id=self.nat_ip_id,
            nat_ip_name=self.nat_ip_name,
            status=self.status,
            using_status=self.using_status)


def get_nat_ip(id: Optional[builtins.str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNatIpResult:
    """
    Data Source schema for Byteplus::NatGateway::NatIp


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:natgateway/getNatIp:getNatIp', __args__, opts=opts, typ=GetNatIpResult).value

    return AwaitableGetNatIpResult(
        id=pulumi.get(__ret__, 'id'),
        is_default=pulumi.get(__ret__, 'is_default'),
        nat_gateway_id=pulumi.get(__ret__, 'nat_gateway_id'),
        nat_ip=pulumi.get(__ret__, 'nat_ip'),
        nat_ip_description=pulumi.get(__ret__, 'nat_ip_description'),
        nat_ip_id=pulumi.get(__ret__, 'nat_ip_id'),
        nat_ip_name=pulumi.get(__ret__, 'nat_ip_name'),
        status=pulumi.get(__ret__, 'status'),
        using_status=pulumi.get(__ret__, 'using_status'))
def get_nat_ip_output(id: Optional[pulumi.Input[builtins.str]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetNatIpResult]:
    """
    Data Source schema for Byteplus::NatGateway::NatIp


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:natgateway/getNatIp:getNatIp', __args__, opts=opts, typ=GetNatIpResult)
    return __ret__.apply(lambda __response__: GetNatIpResult(
        id=pulumi.get(__response__, 'id'),
        is_default=pulumi.get(__response__, 'is_default'),
        nat_gateway_id=pulumi.get(__response__, 'nat_gateway_id'),
        nat_ip=pulumi.get(__response__, 'nat_ip'),
        nat_ip_description=pulumi.get(__response__, 'nat_ip_description'),
        nat_ip_id=pulumi.get(__response__, 'nat_ip_id'),
        nat_ip_name=pulumi.get(__response__, 'nat_ip_name'),
        status=pulumi.get(__response__, 'status'),
        using_status=pulumi.get(__response__, 'using_status')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetEndpointServiceResult',
    'AwaitableGetEndpointServiceResult',
    'get_endpoint_service',
    'get_endpoint_service_output',
]

@pulumi.output_type
class GetEndpointServiceResult:
    """
    A collection of values returned by getEndpointService.
    """
    def __init__(__self__, auto_accept_enabled=None, billing_type=None, business_status=None, create_time=None, description=None, id=None, ip_address_versions=None, payer=None, private_dns_enabled=None, private_dns_name=None, private_dns_name_configuration=None, private_dns_type=None, project_name=None, resources=None, service_domain=None, service_id=None, service_name=None, service_name_managed=None, service_name_suffix=None, service_owner=None, service_resource_type=None, service_type=None, status=None, tags=None, update_time=None, wildcard_domain_enabled=None, zone_ids=None):
        if auto_accept_enabled and not isinstance(auto_accept_enabled, bool):
            raise TypeError("Expected argument 'auto_accept_enabled' to be a bool")
        pulumi.set(__self__, "auto_accept_enabled", auto_accept_enabled)
        if billing_type and not isinstance(billing_type, int):
            raise TypeError("Expected argument 'billing_type' to be a int")
        pulumi.set(__self__, "billing_type", billing_type)
        if business_status and not isinstance(business_status, str):
            raise TypeError("Expected argument 'business_status' to be a str")
        pulumi.set(__self__, "business_status", business_status)
        if create_time and not isinstance(create_time, str):
            raise TypeError("Expected argument 'create_time' to be a str")
        pulumi.set(__self__, "create_time", create_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ip_address_versions and not isinstance(ip_address_versions, list):
            raise TypeError("Expected argument 'ip_address_versions' to be a list")
        pulumi.set(__self__, "ip_address_versions", ip_address_versions)
        if payer and not isinstance(payer, str):
            raise TypeError("Expected argument 'payer' to be a str")
        pulumi.set(__self__, "payer", payer)
        if private_dns_enabled and not isinstance(private_dns_enabled, bool):
            raise TypeError("Expected argument 'private_dns_enabled' to be a bool")
        pulumi.set(__self__, "private_dns_enabled", private_dns_enabled)
        if private_dns_name and not isinstance(private_dns_name, str):
            raise TypeError("Expected argument 'private_dns_name' to be a str")
        pulumi.set(__self__, "private_dns_name", private_dns_name)
        if private_dns_name_configuration and not isinstance(private_dns_name_configuration, dict):
            raise TypeError("Expected argument 'private_dns_name_configuration' to be a dict")
        pulumi.set(__self__, "private_dns_name_configuration", private_dns_name_configuration)
        if private_dns_type and not isinstance(private_dns_type, str):
            raise TypeError("Expected argument 'private_dns_type' to be a str")
        pulumi.set(__self__, "private_dns_type", private_dns_type)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if resources and not isinstance(resources, list):
            raise TypeError("Expected argument 'resources' to be a list")
        pulumi.set(__self__, "resources", resources)
        if service_domain and not isinstance(service_domain, str):
            raise TypeError("Expected argument 'service_domain' to be a str")
        pulumi.set(__self__, "service_domain", service_domain)
        if service_id and not isinstance(service_id, str):
            raise TypeError("Expected argument 'service_id' to be a str")
        pulumi.set(__self__, "service_id", service_id)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if service_name_managed and not isinstance(service_name_managed, str):
            raise TypeError("Expected argument 'service_name_managed' to be a str")
        pulumi.set(__self__, "service_name_managed", service_name_managed)
        if service_name_suffix and not isinstance(service_name_suffix, str):
            raise TypeError("Expected argument 'service_name_suffix' to be a str")
        pulumi.set(__self__, "service_name_suffix", service_name_suffix)
        if service_owner and not isinstance(service_owner, str):
            raise TypeError("Expected argument 'service_owner' to be a str")
        pulumi.set(__self__, "service_owner", service_owner)
        if service_resource_type and not isinstance(service_resource_type, str):
            raise TypeError("Expected argument 'service_resource_type' to be a str")
        pulumi.set(__self__, "service_resource_type", service_resource_type)
        if service_type and not isinstance(service_type, str):
            raise TypeError("Expected argument 'service_type' to be a str")
        pulumi.set(__self__, "service_type", service_type)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if update_time and not isinstance(update_time, str):
            raise TypeError("Expected argument 'update_time' to be a str")
        pulumi.set(__self__, "update_time", update_time)
        if wildcard_domain_enabled and not isinstance(wildcard_domain_enabled, bool):
            raise TypeError("Expected argument 'wildcard_domain_enabled' to be a bool")
        pulumi.set(__self__, "wildcard_domain_enabled", wildcard_domain_enabled)
        if zone_ids and not isinstance(zone_ids, list):
            raise TypeError("Expected argument 'zone_ids' to be a list")
        pulumi.set(__self__, "zone_ids", zone_ids)

    @property
    @pulumi.getter(name="autoAcceptEnabled")
    def auto_accept_enabled(self) -> builtins.bool:
        """
        是否自动接受终端节点连接。true：终端节点服务自动接受终端节点连接。false：终端节点服务不会自动接受终端节点连接，需要调用EnableVpcEndpointConnection接口手动接受。
        """
        return pulumi.get(self, "auto_accept_enabled")

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> builtins.int:
        """
        终端节点服务的计费类型。0：不计费。3：按量计费。
        """
        return pulumi.get(self, "billing_type")

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> builtins.str:
        """
        终端节点服务是否被锁定。Normal：正常。FinancialLocked：被锁定。说明该参数返回为空时，表示终端节点服务未锁定。
        """
        return pulumi.get(self, "business_status")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> builtins.str:
        """
        终端节点服务的创建时间。
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        终端节点服务的描述信息。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="ipAddressVersions")
    def ip_address_versions(self) -> Sequence[builtins.str]:
        """
        终端节点服务的IP协议类型。返回值中仅包含ipv4时，说明该终端节点服务为IPv4类型，仅支持提供IPv4服务。返回值中同时包含ipv4和ipv6时，说明该终端节点服务为双栈类型，支持同时提供IPv4和IPv6服务。
        """
        return pulumi.get(self, "ip_address_versions")

    @property
    @pulumi.getter
    def payer(self) -> builtins.str:
        """
        私网连接的付费账号。Endpoint：终端节点账号。EndpointService：终端节点服务账号。
        """
        return pulumi.get(self, "payer")

    @property
    @pulumi.getter(name="privateDnsEnabled")
    def private_dns_enabled(self) -> builtins.bool:
        """
        终端节点服务是否启用私有DNS名称。false：未启用。true：已启用。
        """
        return pulumi.get(self, "private_dns_enabled")

    @property
    @pulumi.getter(name="privateDnsName")
    def private_dns_name(self) -> builtins.str:
        """
        终端节点服务的私有DNS名称。参数PrivateDNSEnabled返回值为false时，该参数返回空。
        """
        return pulumi.get(self, "private_dns_name")

    @property
    @pulumi.getter(name="privateDnsNameConfiguration")
    def private_dns_name_configuration(self) -> 'outputs.GetEndpointServicePrivateDnsNameConfigurationResult':
        """
        终端节点服务私有DNS名称的配置信息。说明PrivateDNSType为private时，不返回该参数。
        """
        return pulumi.get(self, "private_dns_name_configuration")

    @property
    @pulumi.getter(name="privateDnsType")
    def private_dns_type(self) -> builtins.str:
        """
        私有DNS名称的域名类型。public：公网。说明未开通自定义私网域名功能时，不返回该参数。
        """
        return pulumi.get(self, "private_dns_type")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        终端节点服务所属的项目名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def resources(self) -> Sequence['outputs.GetEndpointServiceResourceResult']:
        """
        终端节点服务提供服务的资源。
        """
        return pulumi.get(self, "resources")

    @property
    @pulumi.getter(name="serviceDomain")
    def service_domain(self) -> builtins.str:
        """
        终端节点服务的服务域名。
        """
        return pulumi.get(self, "service_domain")

    @property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> builtins.str:
        """
        终端节点服务的ID。
        """
        return pulumi.get(self, "service_id")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        """
        终端节点服务的名称。
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter(name="serviceNameManaged")
    def service_name_managed(self) -> builtins.str:
        """
        是否为托管终端节点服务。false：非托管终端节点服务。true：托管终端节点服务。说明终端节点服务所属账号未开通托管终端节点服务功能时，不返回该参数。
        """
        return pulumi.get(self, "service_name_managed")

    @property
    @pulumi.getter(name="serviceNameSuffix")
    def service_name_suffix(self) -> builtins.str:
        """
        终端节点服务的名称后缀。设置名称后缀后，系统会按照com.volces.privatelink.<地域ID>.<名称后缀>的格式生成终端节点服务的名称。说明该参数正在邀测中，如需使用不同名称后缀区分业务，请联系客户经理。
        """
        return pulumi.get(self, "service_name_suffix")

    @property
    @pulumi.getter(name="serviceOwner")
    def service_owner(self) -> builtins.str:
        """
        当前服务主体。
        """
        return pulumi.get(self, "service_owner")

    @property
    @pulumi.getter(name="serviceResourceType")
    def service_resource_type(self) -> builtins.str:
        """
        服务资源的类型。CLB：负载均衡CLB。ALB：应用型负载均衡ALB。RDSMySQL：云数据库 MySQL版。
        """
        return pulumi.get(self, "service_resource_type")

    @property
    @pulumi.getter(name="serviceType")
    def service_type(self) -> builtins.str:
        """
        终端节点服务的类型。Interface：接口终端节点服务。
        """
        return pulumi.get(self, "service_type")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        终端节点服务的状态。Creating：创建中。Pending：配置修改中。Available：可用。Deleting：删除中。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetEndpointServiceTagResult']:
        """
        终端节点服务的标签信息。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> builtins.str:
        """
        终端节点服务的最近操作时间。
        """
        return pulumi.get(self, "update_time")

    @property
    @pulumi.getter(name="wildcardDomainEnabled")
    def wildcard_domain_enabled(self) -> builtins.bool:
        """
        是否启用通配符域名。true：启用。false：未启用。
        """
        return pulumi.get(self, "wildcard_domain_enabled")

    @property
    @pulumi.getter(name="zoneIds")
    def zone_ids(self) -> Sequence[builtins.str]:
        """
        终端节点服务提供服务的可用区。说明参数ServiceResourceType返回值为RDSMySQL时，该参数返回空值。
        """
        return pulumi.get(self, "zone_ids")


class AwaitableGetEndpointServiceResult(GetEndpointServiceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEndpointServiceResult(
            auto_accept_enabled=self.auto_accept_enabled,
            billing_type=self.billing_type,
            business_status=self.business_status,
            create_time=self.create_time,
            description=self.description,
            id=self.id,
            ip_address_versions=self.ip_address_versions,
            payer=self.payer,
            private_dns_enabled=self.private_dns_enabled,
            private_dns_name=self.private_dns_name,
            private_dns_name_configuration=self.private_dns_name_configuration,
            private_dns_type=self.private_dns_type,
            project_name=self.project_name,
            resources=self.resources,
            service_domain=self.service_domain,
            service_id=self.service_id,
            service_name=self.service_name,
            service_name_managed=self.service_name_managed,
            service_name_suffix=self.service_name_suffix,
            service_owner=self.service_owner,
            service_resource_type=self.service_resource_type,
            service_type=self.service_type,
            status=self.status,
            tags=self.tags,
            update_time=self.update_time,
            wildcard_domain_enabled=self.wildcard_domain_enabled,
            zone_ids=self.zone_ids)


def get_endpoint_service(id: Optional[builtins.str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEndpointServiceResult:
    """
    Data Source schema for Byteplus::PrivateLink::EndpointService


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:privatelink/getEndpointService:getEndpointService', __args__, opts=opts, typ=GetEndpointServiceResult).value

    return AwaitableGetEndpointServiceResult(
        auto_accept_enabled=pulumi.get(__ret__, 'auto_accept_enabled'),
        billing_type=pulumi.get(__ret__, 'billing_type'),
        business_status=pulumi.get(__ret__, 'business_status'),
        create_time=pulumi.get(__ret__, 'create_time'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        ip_address_versions=pulumi.get(__ret__, 'ip_address_versions'),
        payer=pulumi.get(__ret__, 'payer'),
        private_dns_enabled=pulumi.get(__ret__, 'private_dns_enabled'),
        private_dns_name=pulumi.get(__ret__, 'private_dns_name'),
        private_dns_name_configuration=pulumi.get(__ret__, 'private_dns_name_configuration'),
        private_dns_type=pulumi.get(__ret__, 'private_dns_type'),
        project_name=pulumi.get(__ret__, 'project_name'),
        resources=pulumi.get(__ret__, 'resources'),
        service_domain=pulumi.get(__ret__, 'service_domain'),
        service_id=pulumi.get(__ret__, 'service_id'),
        service_name=pulumi.get(__ret__, 'service_name'),
        service_name_managed=pulumi.get(__ret__, 'service_name_managed'),
        service_name_suffix=pulumi.get(__ret__, 'service_name_suffix'),
        service_owner=pulumi.get(__ret__, 'service_owner'),
        service_resource_type=pulumi.get(__ret__, 'service_resource_type'),
        service_type=pulumi.get(__ret__, 'service_type'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        update_time=pulumi.get(__ret__, 'update_time'),
        wildcard_domain_enabled=pulumi.get(__ret__, 'wildcard_domain_enabled'),
        zone_ids=pulumi.get(__ret__, 'zone_ids'))
def get_endpoint_service_output(id: Optional[pulumi.Input[builtins.str]] = None,
                                opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetEndpointServiceResult]:
    """
    Data Source schema for Byteplus::PrivateLink::EndpointService


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:privatelink/getEndpointService:getEndpointService', __args__, opts=opts, typ=GetEndpointServiceResult)
    return __ret__.apply(lambda __response__: GetEndpointServiceResult(
        auto_accept_enabled=pulumi.get(__response__, 'auto_accept_enabled'),
        billing_type=pulumi.get(__response__, 'billing_type'),
        business_status=pulumi.get(__response__, 'business_status'),
        create_time=pulumi.get(__response__, 'create_time'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        ip_address_versions=pulumi.get(__response__, 'ip_address_versions'),
        payer=pulumi.get(__response__, 'payer'),
        private_dns_enabled=pulumi.get(__response__, 'private_dns_enabled'),
        private_dns_name=pulumi.get(__response__, 'private_dns_name'),
        private_dns_name_configuration=pulumi.get(__response__, 'private_dns_name_configuration'),
        private_dns_type=pulumi.get(__response__, 'private_dns_type'),
        project_name=pulumi.get(__response__, 'project_name'),
        resources=pulumi.get(__response__, 'resources'),
        service_domain=pulumi.get(__response__, 'service_domain'),
        service_id=pulumi.get(__response__, 'service_id'),
        service_name=pulumi.get(__response__, 'service_name'),
        service_name_managed=pulumi.get(__response__, 'service_name_managed'),
        service_name_suffix=pulumi.get(__response__, 'service_name_suffix'),
        service_owner=pulumi.get(__response__, 'service_owner'),
        service_resource_type=pulumi.get(__response__, 'service_resource_type'),
        service_type=pulumi.get(__response__, 'service_type'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        update_time=pulumi.get(__response__, 'update_time'),
        wildcard_domain_enabled=pulumi.get(__response__, 'wildcard_domain_enabled'),
        zone_ids=pulumi.get(__response__, 'zone_ids')))
